\name{CoCoRaw-internal}
\title{Internal CoCoRaw objects}
\alias{.base}
\alias{.clean.up}
\alias{.current}
\alias{.decompose.models}
\alias{.dispose.of.fitted.values}
\alias{.eh.enter.base.model}
\alias{.enter.double.list}
\alias{.enter.n.interactions}
\alias{.First.lib}
\alias{.fix.edges}
\alias{.names.from.model}
\alias{.omit.test}
\alias{.onAttach}
\alias{.onLoad}
\alias{.plotCoCo}
\alias{.return.complex}
\alias{.set.datastructure}
\alias{.set.ic}
\alias{.set.switch}
\alias{.show.log.lik}
\alias{.split.model.gc}
\alias{.split.name.set}
\alias{.sub.split.names}

%    \alias{CoCoIdClass-class}
%    \alias{CoCoClass-class}
%    \alias{CoCoModelClass-class}
%    \alias{CoCoTestClass-class}
%    
%    \alias{label} % CoCoTestClass-method
%    \alias{testLabel} % CoCoTestClass-method
%    \alias{width} % CoCoTestClass-method
%    \alias{testWidth} % CoCoTestClass-method
%    
%    \alias{dynamic.Graph} % CoCoModelClass-method
%    \alias{dynamic.Graph.Old} % CoCoModelClass-method
%    \alias{modifyModel} % CoCoModelClass-method
%    \alias{subModifyModel} % CoCoModelClass-method
%    \alias{subModifyModel.Old} % CoCoModelClass-method
%    \alias{testEdge} % CoCoModelClass-method
%    \alias{testEdge.Old} % CoCoModelClass-method
%    
%    \alias{makeModel} % CoCoObjects
%    \alias{newCoCoTestObject} % CoCoObjects
%    \alias{recover.coco.model} % CoCoObjects
%    

     \alias{coco.init} % From CoCoCore

%    \alias{coco.resume} % From CoCoCore
%    \alias{coco.start} % From CoCoCore
%    \alias{currentCoCo} % From CoCoObjects
%    \alias{endCoCo} % From CoCoRaw
%    \alias{is.number} % From CoCoCore
%    \alias{make.cococg} % From CoCoCore
%    \alias{make.coco} % From CoCoCore
%    \alias{makeCurrentCoCo} % From CoCoObjects
%    \alias{make.model} % From CoCoCore
%    \alias{my.assign} % From CoCoCore
%    \alias{quitCoCo} % From CoCoRaw

\description{Internal CoCoRaw and imported objects.}
\details{Some of these are not to be called by the user.}
\keyword{internal}

\eof
\name{backward}

\alias{backward}
\alias{forward}

\title{ Stepwise model selection by backward elimination and
        forward selection of edges or interaction terms }

\description{ This function perform (depth first) search for a single model
	      with all edges or interaction terms significant (backward),
	      or all terms not in the model not significant (forward).
	      The function can also be used to compute tests for
	      all terms in the model or all terms not in the model.
	      }

\usage{
backward(sorted = FALSE, reversed = FALSE, only = FALSE, short = FALSE, 
	 p.accepted = FALSE, p.rejected = FALSE, decomposable.mode = NULL, 
	 coherent = FALSE, headlong = FALSE, recursive = FALSE, 
         follow = FALSE, 
         least.significant = TRUE, 
	 components = NULL, p.components = FALSE, 
	 separators = FALSE, p.separators = FALSE, 
         edges = TRUE, model = FALSE, fix.edges = NULL, data = NULL, 
	 object = .object.of.model(model, data = data, ...), ...)

forward(sorted = FALSE, reversed = FALSE, only = FALSE, short = FALSE, 
        p.accepted = FALSE, p.rejected = FALSE, decomposable.mode = NULL, 
	coherent = FALSE, headlong = FALSE, recursive = FALSE, 
	all.significant = TRUE, 
	components = NULL, p.components = FALSE, 
	separators = FALSE, p.separators = FALSE, 
	edges = TRUE, model = FALSE, fix.edges = NULL, data = NULL, 
	object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{sorted}{ Logical, if \code{sorted} is TRUE
		 then a list of tests is printed
		 sorted according to the selected
                 p-value (statistic, if \code{IC} is selected).
		 For backward the p-values are ordered in
                 increasing order (\code{IC} decreasing),
		 and for forward the p-values are ordered in
                 decreasing order (\code{IC} increasing).
		 The least significant edge is then last for backward,
		 and the most significant edge is then last for forward.
                 }
  \item{reversed}{ Logical, if \code{reversed} is TRUE then
	       the sorted list is printed in reverse order. }
  \item{only}{ Logical, if \code{only} is TRUE then only
	       the sorted list is printed. }
  \item{short}{ Logical, if \code{short} is TRUE then only a short report
                is printed: The test of the edge removed (entered) at
                each cycle. 

		If \code{short} is TRUE and \code{dump}
		(\code{\link{optionsCoCo}}) also is TRUE
		then for each completed set of backward (e.i. each removal
		of an edge or interaction terms), the dump file is rewinded,
		and a report of rejected, accepted, eligible terms
		and the model resulting of the step is printed on the file.
		In the following step of the backward elimination each tested
		term and the selected test statistic for the test of the term
		is printed on the dump file. Similar for forward.
		}

  \item{p.accepted}{ Numeric, edges and interaction terms with tests with
		     p-value (or minus the \code{IC} value)
		     greater than \code{p.accepted} are accepted
		     for removal in backward. 

		     If \code{coherent} is TRUE for
		     forward then terms with 
		     p-value (or minus the \code{IC} value)
		     greater than \code{p.accepted} are not
		     eligible for entering in sub sequential
		     cycles of the forward selection.
		     }

  \item{p.rejected}{ Numeric, and interaction terms with tests with
		     p-value (or minus the \code{IC} value)
		     smaller than \code{p.rejected} are rejected,
		     and thus entered into the model in forward
		     (according to \code{all.significant}). 

		     If \code{coherent} is TRUE for
		     backward then terms with 
		     p-value (or minus the \code{IC} value)
		     smaller than \code{p.rejected} are not
		     eligible for removal in sub sequential
		     cycles of the backward elimination.
		     }

  \item{decomposable.mode}{ Logical, if \code{decomposable.mode} is TRUE
			    then only decomposable models are visited. }

  \item{coherent}{ Logical, if \code{coherent} then the principle of
		   coherence is applied: Once an edge in backward (forward)
		   is rejected (accepted) it is no more tested for
		   removal (entering).
		   }
  \item{headlong}{ Logical, if \code{headlong} is TRUE then in each cycle,
		   e.i. visiting of the edges or interaction terms of the
		   model, terms are only visited until a term is found
		   to remove or enter. 
		   In backward edges are visited until an edge with
		   a p-value (or minus the \code{IC} value)
		   greater than \code{p.accepted} is found,
		   and in forward edges are visited until an edge with
		   a p-value (or minus the \code{IC} value)
		   smaller than \code{p.rejected} is found.
		   }
  \item{recursive}{ Logical, if \code{recursive} is TRUE then cycles
		    of visiting edges or interaction terms are repeated
		    until no more edges are removed in backward
		    and until no more edges are added in forward. }
  \item{follow}{ Logical, if \code{follow} is TRUE then tests in backward
		 are performed against the model selected in the previous
		 cycle, else tests are performed against the BASE model.
		 The option is not available for forward. }
  \item{least.significant}{ Logical, if \code{least.significant} is TRUE then 
			    the least significant edge is removed in backward,
			    else all non significant edges are removed.
		 The option is not available for forward. }
  \item{all.significant}{ Logical, if \code{all.significant} is TRUE then
			  all significant edges are entered in forward,
			  else only the most significant edge is entered.
			  The option is not available for backward. }
  \item{components}{ Logical, if \code{components} is TRUE,
		     then common decompositions of the two models
		     of each tests are found.
		     If any p-value (or minus the \code{IC} value) of
		     the tests on the resulting components is less than 
		     \code{p.components} then the test is rejected. }
  \item{p.components}{ Numeric, edges
		       with a p-value (or minus the \code{IC} value)
		       less than the value \code{p.components}
		       for any component
		       is rejected, if \code{components} is TRUE. }
  \item{separators}{ Logical, if \code{separators} is TRUE, then for each
		     edge all separators of the two vertices of the edge
		     is found, and the edge is rejected, if for any of
		     these separators the two variables not are conditional
		     independent, determined by \code{p.separators}. }
  \item{p.separators}{ Numeric, edges 
		       with a p-value (or minus the \code{IC} value) 
		       less than the value \code{p.separators}
		       for any separator
		       is rejected, if \code{separators} is TRUE. }
  \item{edges}{ Logical, if \code{edges} is TRUE, then in each cycle
		edges of the model are visited, else the maximal interaction
		terms are visited. }
  \item{model}{ See \code{\link{returnModel}}. }
  \item{fix.edges}{ A character string with a generating class.
		    Edges in \code{fix.edges} are not eligible for removal
		    in backward, and are not eligible for entering in forward.
		    if \code{fix.edges} is NULL, default, the fixing of the
		    previous backward or forward is retained. 
		    Use \code{fix.edges = ""} to clear fixing of edges.
		    }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ Note also the options of the sections \code{"tests"}
       (\code{\link{optionsCoCo}}).

       \code{p.accepted}, \code{p.rejected}, \code{p.components},
       \code{p.separators} when set to a value not FALSE
       will set these options for the CoCo object.
       If the arguments are not given to backward and forward
       the the values of the CoCo objects will be used.

       The arguments \code{decomposable.mode} and \code{separators}  
       when different from NULL sets respectively the
       options \code{decomposable.mode} and \code{partitioning}.

       Note that to use \code{BIC} both \code{IC} and \code{BIC}
       has to be set to TRUE, since \code{IC} controls
       whether to use p-values or IC-values,
       and \code{BIC} controls which IC-value to use.
       }

\seealso{ \code{\link{editModel}} and \code{\link{eh}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{cleanData}
\alias{cleanData}

\title{ Remove cases from cells set to zero by structurally }

\description{ Remove the cases in cells that are defined to be
	      zero by structure. }

\usage{
cleanData(data = NULL, object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{enterQtable}} and \code{\link{enterQlist}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{disposeOfEh}
\alias{disposeOfEh}

\title{ Dispose of the model classes of the EH procedure }

\description{ Dispose of model classes of the EH procedure.
}

\usage{
disposeOfEh(code = "all", data = NULL, 
            object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{code}{ A character string. The argument
	       \code{code} should be
	       \code{"all"} (all four classes),
	       \code{"duals"} (the two duals),
	       \code{"a.dual"} (the a-dual),
	       \code{"r.dual"} (the r-dual),
	       \code{"classes"} (accepted and rejected models),
	       \code{"accepted"} (accepted models), or
	       \code{"rejected"} (rejected models).
	  }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{eh}}. }

\examples{
library(CoCo);
data(Reinis);

CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);
eh(strategy= "smallest", object = CoCoObject);
disposeOfEh(object = CoCoObject);
eh(strategy= "alternating", object = CoCoObject);
disposeOfEh(object = CoCoObject);
eh(strategy= "rough", object = CoCoObject);
disposeOfEh(object = CoCoObject);
endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{disposeOfModel}
\alias{disposeOfModel}

\title{ Dispose of models }

\description{ Dispose of models of the model list in the CoCo object. }

\usage{
disposeOfModel(model = FALSE, a = FALSE, b = FALSE, data = NULL, 
               object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{showModel}}. }
  \item{a}{ See \code{\link{showModel}}. }
  \item{b}{ See \code{\link{showModel}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{enterModel}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{disposeOfQtable}
\alias{disposeOfQtable}

\title{ Dispose of Q-tables and Q-lists (structurally zero cells) }

\description{ Dispose of a Q-table or a Q-list. }

\usage{
disposeOfQtable(set, data = NULL, 
                object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{set}{ A character string identifying the Q-table or Q-list
	      to dispose of by the \code{set} 
	      of names of the variables of the table. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{enterQlist}} and \code{\link{enterQtable}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{editModel}
\alias{editModel}

\title{ Edit model }

\description{ Edit or transform models. }

\usage{
editModel(action = NULL, modification = NULL, model = FALSE, 
	  result.form = "maximal-interaction-terms", omit.test = TRUE, 
	  make.model = FALSE, return.test = FALSE, push.pop = FALSE, 
	  edges = TRUE, dispose = FALSE, data = NULL, 
	  object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{action}{ A character string. 
		 The argument \code{action} should be
		 \code{"marginal.model"},  
		 \code{"collaps.model"},  
		 \code{"generate.decomposable"},  
		 \code{"generate.graphical"}, \   
		 \code{"generate.skeleton"}, \   
		 \code{"generate.moral"},  
		 \code{"dual.to.normal"},  
		 \code{"nor-} \code{mal.to.dual"},  
		 \code{"drop.factor"},  
		 \code{"drop.edges"},  
		 \code{"add.edges"},  
		 \code{"drop.-} \code{interactions"},  
		 \code{"add.interactions"},  
		 \code{"reduce.generator"},  
		 \code{"remove.-} \code{generator"}, \ 
		 \code{"remove.total.interaction"}, \ 
		 \code{"meet.of.models"}, \ (or \code{"intersection"}), 
		 \code{"join.of.models"}, (or \code{"union"}), 
		 \code{"difference.of.-} \code{models"},  
		 or \code{"decompose.models"}.
		 See the section "Details" below. }
  \item{modification}{ A character string or a model as \code{model}.
		       The argument \code{modification}
		       should be a set, generating class,
		       or a model. }
  \item{model}{ Numeric, model object, text string, or logical.
	 A numeric should give a valid model number in the \code{object},
         see \code{\link{makeCurrent}} about the model list.
         The argument can also be a CoCo model object, see
         \code{\link[CoCoObjects]{makeModel}} about creating model objects.
         A text string can give the model as a generating class
	 (or generating classes in MIM-form for mixed models), see
         \code{\link{enterModel}} for the notation of models.
         The text strings \code{"base"}, \code{"current"}, or \code{"last"}
         refers to the three models.
         The default value \code{"current"} for the CURRENT model
         can also be given as the logical FALSE. }
  \item{result.form}{ A character string.
		      Currently only \code{"maximal-interaction-terms"}
		      is implemented for \code{result.form}. }
  \item{omit.test}{ Logical, if \code{omit.test} is TRUE then
		    the resulting model is not tested against the
		    argument model. }
  \item{make.model}{ Logical, if \code{make.model} is TRUE then
		     a model object of the model resulting
		     of the action is returned. }
  \item{return.test}{ Logical, if \code{return.test} is TRUE then
		      a character string with the model resulting
		      of the action is returned. }
  \item{push.pop}{ Logical, if \code{push.pop} is TRUE, the model argument
		   is numeric and the object argument is a CoCoCg object
		   then model pointers are restored by less calls of CoCoCg. 
		   See also \code{\link{returnModelNumber}}
		   and \code{\link{makeCurrent}}. }
  \item{edges}{ A logical for difference between models.
		If \code{edges} is TRUE then the edges not in both models
		are returned. }
  \item{dispose}{ Logical, if \code{dispose} is TRUE then the model
		  resulting of the action is in the CoCo object,
		  and a character string with the model is returned. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

\details{
	\itemize{
	\item{Marginal model }{:}   
	\item{Collaps model }{:}   
	\item{Generate decomposable }{:}   
	\item{Generate graphical }{:}   
	\item{Generate skeleton }{:}   
	\item{Generate moral }{:}   
	\item{Dual to normal }{:}   
	\item{Normal to dual }{:}   
	\item{Drop factor }{:}   
	\item{Drop edges }{:}   
	\item{Add edges }{:}   
	\item{Drop interactions }{:}   
	\item{Add interactions }{:}   
	\item{Reduce generator }{:}   
	\item{Remove generator }{:}   
	\item{Remove total interaction }{:}   
	\item{Meet of models }{: (or \code{"intersection"}) }
	\item{Join of models }{: (or \code{"union"}) }
	\item{Difference of models }{:}   
	\item{Decompose models }{:}   
	}
 }

\value{ The logical TRUE,
	a charaterstring with a generating class of a model,
	a model object,
	or a vector of numerics (as \code{\link{returnTest}}) for a test.
	}

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{enterModel}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{eh}
\alias{eh}

\title{ The Edwards and Havranek model search procedure }

\description{ After using the
	      "Fast Procedure for Model Search", the EH-procedure,
	      by Edwards and Havranek (1985, 1985) any model
	      can be labeled as accepted or as rejected.	
	      By the principles of weak acceptance, weak rejection,
	      and coherence, the search space of all hierarchical
	      graphical, or decomposable models is divided into
	      two sets of models: The class of minimal acceptable models,
	      and the class of maximal rejected models.
}

\usage{
eh(strategy = c("smallest", "alternating", "rough")[1],
   sub.class = c("decomposable", "graphical", "hierarchical")[2],
   p.accepted = FALSE,  data = NULL, 
   object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{strategy}{ A character string. 
		   The argument \code{strategy} should be
		   \code{"smallest"}, 
		   \code{"alternating"}, 
		   or \code{"rough"}.
		   See the section "Details" below.
		   }
  \item{sub.class}{ A character string.
		    The argument \code{sub.class} should be
		    \code{"decomposable"}, 
		    \code{"graphical"}, 
		    or \code{"hierarchical"}.
		    See the section "Details" below.
		    }
  \item{p.accepted}{ Numeric, models with p-value greater than
		     \code{p.accepted} are accepted, else they are rejected. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

\details{
    \itemize{
	\item{Smallest    }{: At each cycle, select the dual
			      with fewest models to fit. }   
	\item{Alternating }{: Switch between fitting the a-dual
			      and the r-dual. }   
	\item{Rough 	  }{: Give a rough estimate of the number of
			      models in each dual, and fit the dual
			      with the smallest rough size. }   
    }
    \itemize{
	\item{Decomposable}{: Restrict the search space to decomposable
    models. } 
	\item{Graphical   }{: Restrict the search space to graphical
    models. }
	\item{Hierarchical}{: Set the the search space to hierarchical
    models.}
    }
 }

\value{ TRUE }

\references{Badsberg, J.H. (2001): A guide to CoCo, JSS
            ( http://www.jstatsoft.org/v06/i04/ ).

            Badsberg, J.H. (1996): Xlisp+CoCo, Aalborg University.

            Edwards, D. and Havranek, T. (1985). A fast procedure for
	    model search in multidimensional contingency tables.
	    Biometrika 72: 339-351.

            Edwards, D. and Havranek, T. (1987). A fast model
	    selection procedure for large families of models.
	    J. Amer. Stat. Assoc. 82: 205-231.
}

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{forward}}, \code{\link{backward}},
	  and \code{\link{disposeOfEh}}. }

\examples{ 
library(CoCo);
data(Reinis);

CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);
eh(sub.class = "decomposable", object = CoCoObject);
eh(sub.class = "graphical",    object = CoCoObject);
eh(sub.class = "hierarchical", object = CoCoObject);
endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{ehExtract}
\alias{ehExtract}

\title{ Extract models from the EH-procedure }

\description{ Copy in the CoCo object models from the classes of
	      the EH procedure to the model list. }

\usage{
ehExtract(class, sub.class = FALSE, data = NULL, 
          object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{class}{ A character string. 
		The argument \code{class} should be
	       % \code{"all"}: All four classes,
	       % \code{"duals"}: The two duals,
	       \code{"a.dual"} (the a-dual),
	       \code{"r.dual"} (the r-dual),
	       % \code{"classes"}: Accepted and rejected models,
	       \code{"accepted"} (accepted models), or
	       \code{"rejected"} (rejected models).
	  }
  \item{sub.class}{ A character string. See \code{\link{eh}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{makeCurrent}},
	  \code{\link{ehForceAccept}} and \code{\link{ehForceReject}}. }

\examples{
library(CoCo);
data(Byssinosis38);

CoCoObject <- makeCoCo();
enterTable(Byssinosis38, object = CoCoObject);
eh(object = CoCoObject);
showModel("all", object = CoCoObject);
disposeOfModel("all", object = CoCoObject);
ehExtract(class = "accepted", object = CoCoObject);
showModel("all", object = CoCoObject);
disposeOfModel("all", object = CoCoObject);
ehExtract(class = "rejected", object = CoCoObject);
showModel("all", object = CoCoObject);
disposeOfModel("all", object = CoCoObject);
ehExtract(class = "a.dual", object = CoCoObject);
showModel("all", object = CoCoObject);
disposeOfModel("all", object = CoCoObject);
ehExtract(class = "r.dual", object = CoCoObject);
showModel("all", object = CoCoObject);
disposeOfModel("all", object = CoCoObject);
ehExtract(class = "a.dual", sub.class = "hierarchical", object = CoCoObject);
showModel("all", object = CoCoObject);
disposeOfModel("all", object = CoCoObject);
ehExtract(class = "r.dual", sub.class = "hierarchical", object = CoCoObject);
showModel("all", object = CoCoObject);
endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{ehFindDual}
\alias{ehFindDual}

\title{ Find duals in the EH procedure }

\description{ Find the a-dual, the r-dual, or both duals in the EH procedure
	      without fitting the models. }

\usage{
ehFindDual(dual = "both", sub.class = FALSE, data = NULL, 
           object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{dual}{ A character string. The argument \code{dual} should be
	       \code{"both"} (find both the two duals),
	       \code{"a.dual"} (find the a-dual),
	       or \code{"r.dual"} (find the r-dual).
	  }
  \item{sub.class}{ A character string. See \code{\link{eh}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{eh}} and \code{\link{ehForceAddDualToClass}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{ehFit}
\alias{ehFit}

\title{ Fit and classify models in the EH procedure }

\description{ Fit and classify models in the EH procedure.
	      The models to fit can be
	      models from the current duals of the EH procedure
	      or models from the model list of the CoCo object. 
	      Only a single "step" of the EH-procedure is performed.
	      }

\usage{
ehFit(model = FALSE, a = FALSE, b = FALSE, dual = NULL, 
      sub.class = FALSE, p.accepted = FALSE, data = NULL, 
      object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{showModel}}. }
  \item{a}{ See \code{\link{showModel}}. }
  \item{b}{ See \code{\link{showModel}}. }
  \item{dual}{ A character string. The argument \code{dual} should be
	       \code{"both"} (fit both the two duals),
	       \code{"smallest.dual"} (fit the smallest dual),
	       \code{"largest.dual"} (fit the largest),
	       \code{"a.dual"} (fit the a-dual),
	       or \code{"r.dual"} (fit the r-dual).
	  }
  \item{sub.class}{ A character string. See \code{\link{eh}}. }
  \item{p.accepted}{ A numeric. See \code{\link{eh}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}


\seealso{ \code{\link{eh}}, \code{\link{showModel}},
	  \code{\link{ehForceAccept}}, 
	  and \code{\link{ehForceReject}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{ehForceAccept}
\alias{ehForceAccept}
\alias{ehForceReject}

\title{ Force models into the classes of the EH procedure }

\description{ Models are forced into a model class of the EH-procedure
	      regardless of whether the models are accepted or rejected.
}

\usage{
ehForceAccept(model, a = FALSE, b = FALSE, data = NULL, 
              object = .object.of.model(model, data = data, ...), ...)

ehForceReject(model, a = FALSE, b = FALSE, data = NULL, 
              object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{showModel}}. }
  \item{a}{ See \code{\link{showModel}}. }
  \item{b}{ See \code{\link{showModel}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{eh}}, \code{\link{showModel}},
	  and \code{\link{ehFit}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{ehForceAddDualToClass}
\alias{ehForceAddDualToClass}

\title{ Force a dual into a class of models of the EH procedure }

\description{ Force a dual of the EH procedure into a class
	      without fitting and classifying the models. }

\usage{
ehForceAddDualToClass(dual = "a.dual", class = "accepted", 
                      sub.class = FALSE, data = NULL, 
                      object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{dual}{ A character string. The argument \code{dual} should be
	       \code{"a.dual"} (add the a-dual),
	       or \code{"r.dual"} (add the r-dual).
	       }
  \item{class}{ A character string. The argument \code{class} should be
	       \code{"accepted"} (add the dual to class of accepted models),
	       or \code{"rejected"} (add the dual to class of rejected models).
	       }
  \item{sub.class}{ A character string. See \code{\link{eh}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{eh}} and \code{\link{ehFindDual}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{ehForceFix}
\alias{ehForceFix}

\title{ Fix edges or terms of the models in the EH procedure }

\description{ Force terms into or out of models in the EH procedure.
	      By \code{ehForceFix(gc, fix = "in", ...)} edges (or generators)
	      are forced into all the models in the EH-procedure.
	      By \code{ehForceFix(gc, fix = "out", ...)} all terms 
	      containing a generator in the generating class
	      \code{gc} are excluded from all models considered
	      in the EH-procedure.
}

\usage{
ehForceFix(gc = "what", fix = "out", add.fix = FALSE, redo.fix = FALSE, 
           data = NULL, object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{gc}{  A character string. 
	      The argument \code{gc} is a generating class.
	       }
  \item{fix}{ A character string.  
	      The argument \code{fix} should be
	       \code{"out"} ( ... ),
	       or \code{"in"} ( ... ).
	       }
  \item{add.fix}{ Logical. 
		  \code{ehForceFix(gc, fix = "out", ...)} will clear
		  the fixing set by previous use of
		  \code{ehForceFix(gc, fix = "out", ...)},
		  if \code{add.fix} is FALSE.
		  If \code{add.fix} is TRUE then
		  the terms are added to the fixing.
		  Similar for \code{ehForceFix(gc, fix = "in", ...)}.
		  }
  \item{redo.fix}{ Logical, if \code{redo.fix} is TRUE then
		   the fixing is repeated. 
		  \code{ehForceFix(gc, fix = "out", redo.fix = TRUE, ...)}
		  will redo the combination of the last
		  \code{ehForceFix(gc, fix = "out", ...)} and following
		  \code{ehForceFix(gc, fix = "out", add.fix = TRUE, ...)}.
		  Fixing set by \code{ehForceFix(gc, fix = "in", ...)}
		  is then modified according to the fixing out.
		  Similar for 
		  \code{ehForceFix(gc, fix = "in", redo.fix = TRUE, ...)}.
		  }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

\details{ Terms set by \code{ehForceFix(gc, fix = "out", ...)}
	  is the dual representation of the maximal models considered,
	  see pp. 340 Edwards \& Havranek (1985). To exclude edges
	  in the graphical search only generators with cardinality 2
	  (edges) should be given to \code{ehForceFix(gc, fix = "out", ...)}.

	  }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ Using the function \code{ehForceFix} will only
       set up fixing for future models visited be \code{\link{eh}}.
       Thus if the EH-procedure already has been used the duals and the 
       model classes should be disposed of be \code{\link{disposeOfEh}}.

       \code{ehForceFix(gc, fix = "out", ...)} and 
       \code{ehForceFix(gc, fix = "in", ...)} will interact:

       Terms set by \code{ehForceFix(gc, fix = "in", ...)} 
       are remove from the terms set by
       \code{ehForceFix(gc, fix = "out", ...)}:
       Terms set by \code{ehForceFix(gc, fix = "in", ...)}
       are added to the generating class achieved by transforming
       \code{ehForceFix(gc, fix = "out", ...)}
       from the dual representation to the normal representation,
       and the resulting generating class is transformed back to
       the dual representation.

       Term set by \code{ehForceFix(gc, fix = "out", ...)} 
       are remove from the terms set by
       \code{ehForceFix(gc, fix = "in", ...)}:
       The terms set by \code{ehForceFix(gc, fix = "in", ...)}
       is restricted to the generating class achieved by transforming
       \code{ehForceFix(gc, fix = "out", ...)} from the dual representation
       to the normal representation.
       }

% \section{ToDo}{....}

\seealso{ \code{\link{eh}} and \code{\link{returnFix}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{ehSetBase}
\alias{ehSetBase}

\title{ The base model of the EH procedure }

\description{ Set the base model of the EH procedure.
	      Tests of models in the EH procedure are performed
	      against the saturated model, or the
	      model entered by \code{ehSetBase}.
	      }

\usage{
ehSetBase(model = FALSE, data = NULL,
          object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{returnModel}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ The base model of the EH procedure effects fixing in
       the EH procedure, \code{\link{ehForceFix}}.
       Terms not in the base model of the EH procedure
       are set to be fixed out for the EH procedure,
       e.i., the fixing out is set to the dual representation
       of the model set by \code{ehSetBase}.
       Since there is no distinction between fixing out due to
       \code{ehForceFix(gc, fix = "out", ...)} and due to
       \code{ehSetBase}, and since a larger EH base model
       would give less fixing out in the EH procedure,
       previous fixing out in the EH procedure is canceled
       by \code{ehSetBase}. 
       Use \code{ehForceFix(fix = "out", redo = TRUE, ...)} to
       redo the fixing out in the EH procedure.

       Only terms in the base model of the EH procedure
       can be fixed into the EH procedure. 
       Thus terms set by \code{ehForceFix(gc, fix = "in", ...)}
       might be reduced by \code{ehSetBase}.
       }

% \section{ToDo}{....}

\seealso{ \code{\link{eh}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{ehSetMainEffects}
\alias{ehSetMainEffects}

\title{ Set the main effects of the models in the EH procedure }

\description{ Set which variables to admit in the models in the EH procedure. }

\usage{
ehSetMainEffects(set = "what", data = NULL, 
                 object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{set}{ A character string with the names of the variables. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE, or a character string if the effects are returned. }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ CoCo will work more efficiently,
       if \code{\link{setUseVariables}} is used to restrict
       the EH procedure to a subset of the variables,
       than if \code{\link{ehSetMainEffects}}, \code{\link{ehSetBase}}
       or \code{\link{ehForceFix}} is used. }

% \section{ToDo}{....}

\seealso{ \code{\link{eh}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{emOn}
\alias{emOn}

\title{ Handling of latent variables and missing values by the EM algorithm }

\description{ Turn on or off the use of the EM algorithm
	      for estimating values for missing values. }

\usage{
emOn(hit = FALSE, setslot = TRUE, data = NULL, 
     object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{hit}{ A character string. \code{hit} should be
	       \code{"on"}, \code{"off"}, or \code{"what"}. }
  \item{setslot}{ See \code{\link{enterNames}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{excludeMissing}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{endCoCo}
\alias{endCoCo}
\alias{quitCoCo}

\title{ End a CoCo object }

\description{ End a CoCo object
              and remove the temporary files of the CoCo object. }

\usage{
endCoCo(object = .current.coco, silent = FALSE)

quitCoCo(..., object = .current.coco)
}

\arguments{
  \item{\dots}{ Additional arguments to \code{\link{quit}}. }
  \item{object}{ See \code{\link[CoCoRaw]{exportCoCo}}. }
  \item{silent}{ Logical, if TRUE then CoCo is more \code{silent}. }
}

% \details{ }

% \value{
%   ~Describe the value returned
%   If it is a LIST, use
%   \item{comp1 }{Description of 'comp1'}
%   \item{comp2 }{Description of 'comp2'}
%   ...
% }

\references{ Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{ Jens Henrik Badsberg }

\note{ The distributed source code is only able to handle one concurrent
CoCo object. Use \code{\link{endCoCo}}. }

% \section{ToDo}{....}

\seealso{ \code{\link{coco.init}}. }

% \examples{ }

\keyword{ interface }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{enterDataFrame}
\alias{enterDataFrame}

\title{ Enter a data.frame into a CoCo object }

\description{ Enter a data frame into a CoCo object
	      with declaring the variables. }

\usage{
enterDataFrame(data.frame, to.factor = NULL, missing.values = c("."), 
               setslot = TRUE, data = NULL, 
               object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{data.frame}{ A object of class \code{"data.frame"}.
		     The argument \code{data.frame} is
		     with continuous and discrete variables
		     as respectively numerics and factors. 
		     The names of the variables are extracted from
		     the column names of the \code{data.frame}. }
  \item{to.factor}{ A numeric vector. Numeric columns of \code{data.frame}
		    with indices in the argument \code{to.factor}
		    are converted into factors. }
  \item{missing.values}{ A vector or list of values to be considered as
			 missing values.
			 If the argument \code{missing.values} is not a list
			 then values in \code{missing.values} are considered
			 as missing values for all the discrete variables,
			 that is the factors.
			 If \code{missing.values} is a list,
			 then it should have length equal to
			 the number of columns of the data.frame,
			 and values of the \code{i}-the variable are 
			 considered as missing if they are among the values
			 of the \code{i}-te element of \code{missing.values}.
			 }
  \item{setslot}{ See \code{\link{enterNames}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{enterNames}}. }

\examples{
library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{enterList}
\alias{enterList}
\alias{enterTwoLists}

\title{ Enter a list of cases into a CoCo object }

\description{ Enter a list of cases into a CoCo object. }

\usage{
enterList(discrete, continuous = NULL, accumulated = FALSE, setslot = TRUE, 
          % ncol = FALSE, select.case.fun = FALSE, columns = FALSE, 
          % silent = FALSE, 
          data = NULL, object = .object.of.thing(data = data, ...), ...)

enterTwoLists(discrete, continuous, accumulated = FALSE, setslot = TRUE, 
              % ncol = FALSE, select.case.fun = FALSE, columns = FALSE, 
              % silent = FALSE, 
              data = NULL, object = .object.of.thing(data = data, ...), ...)

}

\arguments{
  \item{discrete}{ A vector (for \code{\link{enterList}})
		   or matrix (for \code{enterTwoList}) of numerics
		   for % the levels of
                   the \code{discrete} variables.
		   For \code{\link{enterList}} the cases should be given
		   one by one in the vector.
		   If \code{your.data} is a \code{data.frame}
		   or a \code{matrix} with cases row by row
		   you will have to give \code{discrete = c(t(your.data))}.
		   For \code{enterTwoList} the data should be given
		   in a \code{data.frame} or a \code{matrix} with
		   cases row by row.
		   }
  \item{continuous}{ A vector or matrix of numerics for the
		     \code{continuous} variables. Similar to \code{discrete}. }
  \item{accumulated}{ Logical, if \code{accumulated} is TRUE then the
		      first integer, count, in \code{discrete} for each
		      \code{"case"} should be the count for that case. 
		      For \code{\link{enterList}} the length of 
		      \code{discrete} thus have to be number of cases times
		      number of variables plus one,
		      For \code{enterTwoList} the number of columns
		      of \code{discrete} is number of variables plus one.
		      }
  % \item{ncol}{ ~~Describe \code{ncol} here~~ }
  % \item{select.case.fun}{ ~~Describe \code{select.case.fun} here~~ }
  % \item{columns}{ ~~Describe \code{columns} here~~ }
  % \item{silent}{ ~~Describe \code{silent} here~~ }

  \item{setslot}{ See \code{\link{enterNames}}. }
  \item{data}{ ( See \code{\link{exportCoCo}}. ) }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ ( Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. ) }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{enterNames}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{enterModel}
\alias{enterModel}

\title{ Enter a model }

\description{ Read a model into the CoCo object. }

\usage{
enterModel(model = "*", order = NULL, set = "*", homogeneous = FALSE, 
           data = NULL, object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{model}{ A character string with a generating class of the model,
		or the 3 generating classes for respectively the 
		discrete, linear and quadratic part of a mixed model. 
		A mixed model can also be given as a single generating class 
		corresponding to the cliques of the 2-section graph 
		of the model.  }
  \item{order}{ Numeric, if \code{order} is set then the model
		with only and all \code{order} interactions among variables
		in the argument \code{set} is entered. }
  \item{set}{ A character string with a set of variables. }
  \item{homogeneous}{ Logical, if \code{homogeneous} is TRUE then
		      a  homogeneous model is read of the single
		      generating class for a mixed model.}
  \item{data}{ ( See \code{\link{exportCoCo}}. ) }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ ( Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. ) }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link[CoCoObjects]{makeModel}},
          \code{\link{editModel}},
          \code{\link{makeCurrent}},
          \code{\link{propertyModel}},
          and \code{\link{showModel}}. }

\examples{
library(CoCo);
data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);

enterModel(".", object = CoCoObject);
showModel("last", object = CoCoObject);

enterModel(order = 1, set = "*", object = CoCoObject);
showModel("last", object = CoCoObject);

enterModel(order = 2, set = "*", object = CoCoObject);
showModel("last", object = CoCoObject);

enterModel(order = 4, set = "*", object = CoCoObject);
showModel("last", object = CoCoObject);

enterModel("*", object = CoCoObject);
showModel("last", object = CoCoObject);

#enterModel("[[BD][BF][G][AD][AEF]]", object = CoCoObject);
 enterModel("[[BC][CE][F][AC][ADE]]", object = CoCoObject);
showModel("last", object = CoCoObject);

#enterModel("BD,BF,G,AD,AEF.;", object = CoCoObject);
 enterModel("BC,CE,F,AC,ADE.;", object = CoCoObject);
showModel("last", object = CoCoObject);

endCoCo(object = CoCoObject);

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);

enterModel(".", object = CoCoObject);
showModel("last", object = CoCoObject);

enterModel(order = 1, set = "*", object = CoCoObject);
showModel("last", object = CoCoObject);

enterModel(order = 2, set = "*", object = CoCoObject);
showModel("last", object = CoCoObject);

enterModel("*", object = CoCoObject);
showModel("last", object = CoCoObject);

enterModel("*", homogeneous = TRUE, object = CoCoObject);
showModel("last", object = CoCoObject);

enterModel("[[ab]] / [[aby][abx]] / [[x^][abxy][y^]]", object = CoCoObject);
showModel("last", object = CoCoObject);

endCoCo(object = CoCoObject);

library(CoCo);
data(Byssinosis38);
CoCoObject <- makeCoCo();
enterTable(Byssinosis38, object = CoCoObject);

enterModel("*", object = CoCoObject);
enterModel("[[:byssinosis:dust:race:sex:smoking:employment]]", object = CoCoObject);

enterModel(paste(c("[[:byssinosis:dust:employment]", 
                   "[:dust:race:sex:employment]", 
                   "[:sex:smoking:employment]]"), collapse = ""), 
		   object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{enterNames}
\alias{enterNames}

\title{ Enter a specification of variables into the CoCo object }

\description{ Enter a specification of variables. 
	      After specifying the variables by the function
	      the observations should be entered by 
	      \code{\link{enterList}} or \code{\link{enterTable}}. }

\usage{
enterNames(names = c("a", "b", "c"), levels = c(2, 2, 2), 
           missing = NULL, setslot = TRUE, data = NULL, 
           object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{names}{ A vector of character strings with the names of the variables.
		If any of the \code{names} of the variables has more than
		one character then all the names should have colon,
		\code{":"}, as the first character. }
  \item{levels}{ A vector of integers.
		 The number of \code{levels}, excluding missing levels,
		 for each of the discrete variable.
		 For continuous variables the number of \code{levels}
		 should be zero, \code{0}.
		 }
  \item{missing}{ A vector of integers.
		 The number of \code{missing} levels 
		 for each variable.  }
  \item{setslot}{ Logical, if \code{setslot} is TRUE then
                  the entered values are added to the CoCo \code{object},
		  such that the \code{object} can be recovered
		  after ending the CoCo \code{object} by,
		  e.g. \code{\link[CoCoRaw]{endCoCo}},
		  or after terminating the R session and restarting R. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ Between \code{\link{enterNames}} and
       \code{\link{enterList}} or \code{\link{enterTable}}
       a subset of the variables can be selected by
       \code{\link{setUseVariables}}.
     }

% \section{ToDo}{....}

\seealso{ \code{\link{setUseVariables}}, \code{\link{excludeMissing}},
	  \code{\link{enterList}}, and \code{\link{enterTable}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{enterQtable}
\alias{enterQtable}
\alias{enterQlist}

\title{ Enter initial values for the IPS algorithm and
	declare cells to be zero by structure }

\description{ Enter a Q-table or Q-list: 
	      Initial values for the IPS-algorithm and
	      the cells of a table to be zero by structure. }

\usage{
enterQtable(set, table, setslot = TRUE, data = NULL, 
            object = .object.of.thing(data = data, ...), ...)

enterQlist(set, list, setslot = TRUE, data = NULL, 
           object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{set}{ A character string giving the \code{set} of variables
	      of the table. }
  \item{table}{ A vector of integers, one for each \code{cells}
	        of the table formed by the cross classification
	        of the variables of \code{set}. }
  \item{list}{ A vector of integers, a list of \code{cells} of the
	       table formed by the cross classification of the
	       variables of \code{set}. }
  \item{setslot}{ See \code{\link{enterNames}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

\details{ Cells equal to zero are by structure zero. 
	  \code{\link{enterQlist}} will enter these cells. }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{disposeOfQtable}}. }

\examples{ 
library(CoCo);

without <- makeCoCo(title = "Without structural zero");
optionsCoCo(digits.table = 6, decimals.table.probabilities = 2, 
            decimals.table.expected = 1, decimals.table.residual = 1);
enterNames("smv", rep(2, 3));
n <- c(11, 2209, 0, 111, 48, 239, 72, 2074);
enterTable(n);
A.1 <- make.model("*");
A.2 <- make.model("mv,vs");
showTest();
endCoCo();

with <- makeCoCo(title = "With structural zero");
optionsCoCo(digits.table = 6, decimals.table.probabilities = 2, 
            decimals.table.expected = 1, decimals.table.residual = 1);
enterNames("smv", rep(2, 3));
n <- c(11, 2209, -1, 111, 48, 239, 72, 2074);
enterTable(n);
returnTable("zero");
B.1 <- make.model("*");
B.2 <- make.model("mv,vs");
showTest();
endCoCo();
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{enterTable}
\alias{enterTable}

\title{ Enter a table of counts of the tables formed by
	cross classifying discrete variables }

\description{ Enter a table of counts of the tables formed by
              cross classifying discrete variables. 
	      If the input is a vector of the counts
	      the table has to be declared by \code{\link{enterNames}}
	      before the use of this function.
	      An \code{\link{array}} of counts with \code{\link{dimnames}}
	      can be entered by \code{\link{enterTable}} without
	      first specifying the variables in the CoCo object.
	      }

\usage{
enterTable(counts, silent = TRUE, setslot = TRUE, missing = NULL, 
           data = NULL, object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{counts}{ Some integers, either a vector
		 or a object of class \code{"array"}.
		 If \code{counts} is a vector then the variables
		 should be defined in the CoCo \code{object} by
		 \code{\link{enterNames}}.
		 If \code{counts} is of class \code{"array"} then
		 the names and number of levels for the variables
		 are extracted from the argument \code{counts}.
		 }
  \item{silent}{ Logical, is \code{silent} CoCo will be more
		 quiet about the cases read. }
  \item{missing}{ A numeric vector of length equal to the
		  number of variables.
		  If \code{counts} is of class \code{"array"}
		  and \code{missing} is not \code{"NULL"} then
		  \code{missing} will define missing levels as
		  \code{\link{enterNames}}. }
  \item{setslot}{ See \code{\link{enterNames}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{enterNames}}. }

\examples{
library(CoCo);
data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);

endCoCo(object = CoCoObject);

library(CoCo);
data(Byssinosis38);
CoCoObject <- makeCoCo();
enterTable(Byssinosis38, object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{excludeMissing}
\alias{excludeMissing}

\title{ Handling of missing values by excluding cases }

\description{ The function controls whether cases with missing values
	      are excluded or if for discrete variables 
	      the levels marked as missing just are additional levels.
	      }

\usage{
excludeMissing(hit = "flop", set = ";", setslot = TRUE, data = NULL, 
               object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{hit}{ A character string.
	      \code{hit} should be
	      \code{"what"},
	      \code{"on"},
	      \code{"off"}, 
	      \code{"flop"} (for switching between \code{"on"} and
	      		      \code{"off"}), 
	      or \code{"in"}.}
  \item{set}{ A character string with the set \code{set} of variables
	      when \code{hit} is set to \code{"in"}. }
  \item{setslot}{ See \code{\link{enterNames}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{emOn}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{exportCoCo}
\alias{exportCoCo}
\alias{importCoCo}

\title{ Write and read the CoCo data and the models to a binary file }

\description{
        Export and import a binary file with the CoCo data and the models. }

\usage{
exportCoCo(file.name, data = NULL, 
           object = .object.of.thing(data = data, ...), ...)

importCoCo(file.name, setslot = TRUE, data = NULL, 
           object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{file.name}{ A character string naming the file to write to. }
  \item{setslot}{ Logical, if \code{setslot} is TRUE then the entered
                  value of \code{file.name} is added to the CoCo \code{object},
		  such that the \code{object} can be recovered
		  after ending the CoCo \code{object} by,
		  e.g. \code{\link[CoCoRaw]{endCoCo}},
		  or after terminating the R session and restarting R. }
  \item{data}{ An optional argument with the "data", only used if
	       the argument \code{object} is not given.
	       If the class of \code{data} is \code{"table"} or \code{"array"},
	       then the table is entered into a pure discrete CoCo object.
	       If the class of \code{data} is \code{"data.frame"}
	       (or \code{"matrix"}),
	       then the data frame is entered into a CoCoCg object. 
	       Columns of class \code{"factor"}
	       will for \code{data} of class \code{"data.frame"}
	       be considered as discrete variables,
  	       and columns of class \code{"numeric"}
	       will be considered as continuous variables.
    	       Columns of class \code{"numeric"} can be converted to
	       discrete variables by the argument \code{to.factor},
	       see \code{\link{enterDataFrame}}.
	       }
  \item{object}{ The CoCo object with the data and models to use.
		 If neither \code{object} or \code{data} is given,
		 then the object \code{.current.coco} of
		 \code{.GlobalEnv} is used as default object,
		 see \code{\link[CoCoObjects]{makeCurrentCoCo}}.
		 }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

\details{ Options, the values of \code{\link{optionsCoCo}} is not exported,
	  as neither is the setting of \code{\link{setUseVariables}},
          \code{\link{excludeMissing}}, and \code{\link{emOn}}.
	  \code{\link{enterQtable}} and \code{\link{enterQlist}}
	  are exported. }

\value{ A character string with the file name \code{file.name}. }

\author{Jens Henrik Badsberg}

\note{ \code{\link{exportCoCo}} and \code{\link{importCoCo}} is 
       intended to facilitate using the same data in R+CoCo, Xlisp+CoCo and 
       standalone CoCo by only entering the data into one of the programs.
       Once the data has been entered into CoCo in one of the three systems,
       the data can be exported, and then imported to a standalone CoCo
       or CoCo loaded under the other system. This will work with the same
       version number of CoCo, and probably also between different platforms
       (Unix, Linux, Windows, etc.). In future versions of CoCo the format
       of the binary file might change, and thus the binary files from
       \code{\link{exportCoCo}} should not be used for storing data.
       }

\seealso{ \code{\link{importCoCo}}. }

\examples{

library(MASS)
data(anorexia)
library(CoCoCg);

# Without "data" require ending the CoCo object:

# exportCoCo("Anorexia.xpt", data = anorexia);
# endCoCo();

# With CoCo object:

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);

exportCoCo("Rats.xpt", object = CoCoObject);

endCoCo(object = CoCoObject);

# Import the first example:

Anorexia <- makeCoCo();
importCoCo("Anorexia.xpt", object = Anorexia);
showOptions("specification");
endCoCo(object = Anorexia);

# Import the second example:

Rats <- makeCoCoCg();
importCoCo("Rats.xpt", object = Rats);
showOptions("specification");
endCoCo(object = Rats);

}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{extractData}
\alias{extractData}

\title{ Extract the data from a CoCo Object }

\description{ Extract the data from a CoCo Object. }

\usage{
extractData(full = FALSE, data = NULL, 
            object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{full}{ Logical, if \code{full} is TRUE then all
	       the varaibles are extracted, that is
	       as without \code{\link{setUseVariables}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{exportCoCo}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{isSubmodel}
\alias{isSubmodel}

\title{ Is the CURRENT model a sub model of the BASE model ? }

\description{
  Return TRUE if the model of the first argument model is
  a sub model of model of the second argument.
}

\usage{
isSubmodel(model.1 = "current", model.2 = "base", data = NULL, 
           object = .object.of.models(model.1, model.2, 
                                      data = data, ...), ...)
}

\arguments{
  \item{model.1}{ Numeric, model object, text string, or logical.
	 A numeric should give a valid model number in the \code{object},
         see \code{\link{makeCurrent}} about the model list.
         The argument can also be a CoCo model object, see
         \code{\link[CoCoObjects]{makeModel}} about creating model objects.
         A text string can give the model as a generating class
	 (or generating classes in MIM-form for mixed models), see
         \code{\link{enterModel}} for the notation of models.
         The text strings \code{"base"}, \code{"current"}, or \code{"last"}
         refers to the three models.
         The default value \code{"current"} for the CURRENT model
         can also be given as the logical FALSE. }
  \item{model.2}{ As the argument \code{model.1}.
         The default value \code{"base"} can here 
	 also be given as the logical FALSE. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

\details{
  Tests if the generating class (classes for mixed models) for the
  first model is a sub class of the generating class of the second model.
  The causal structures of the two models should be the same.
}

\value{
  Logical, TRUE if the first argument is a sub model of the second argument.

  The value NULL is returned (after warnings) if the two models
  is not available.
}

\references{Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{

%      The function aborted with an error, if the models not are available:
%      Now the value NULL is returned after warnings (and extra line return).

       NULL can be used for FALSE.
%      NULL can now be used for FALSE ("current").

%      The function aborted with an error, 
%      if CURRENT and BASE models not were available.
%      Now the missing pointers will be set as specified by the arguments.

       If CURRENT (BASE) is not available the pointer in the CoCo object
       will after the call be as specified by the \code{model.1}
       (\code{model.2}) argument.

       Model arguments should not be \code{"previous"} or \code{"next"}.

%      If BASE if fully specified (with \code{"\^"}) and CURRENT is not
%      the result might currently not be correct in CoCoCg (interchanged).

%      The two first arguments were interchanged !!!

%      Data from model arguments is not implemented.

     }

\seealso{\code{\link{enterModel}}, \code{\link[CoCoObjects]{makeModel}},
         \code{\link{showModel}},
         \code{\link{returnTest}}, \code{\link{propertyModel}}, 
         \code{\link{makeCurrent}}, \code{\link{returnModel}},
         and \code{\link{returnModelNumber}}. }

\examples{
library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, follow = TRUE, 
         object = CoCoObject);

# Show the model list:
showModel("all", object = CoCoObject);

.set.switch(26921, "on");
.set.switch(26931, "on");
.set.switch(11081, "on");
.set.switch(11071, "on");
.set.switch(11061, "on");
.set.switch(6301, "on");

isSubmodel(object = CoCoObject); # TRUE
isSubmodel(1, 4, object = CoCoObject); # FALSE
isSubmodel(4, 1, object = CoCoObject); # TRUE

homogeneModel <- makeModel(enterModel("[[ab]] / [[aby][abx]] / [[x^][abxy][y^]]",
	                   object = CoCoObject));

# Numbers:

n6 <- returnModelNumber(homogeneModel, object = CoCoObject);

isSubmodel(object = CoCoObject); # TRUE
isSubmodel(1, n6, object = CoCoObject); # FALSE
isSubmodel(n6, 1, object = CoCoObject); # TRUE

# Text string with tags:

isSubmodel("base", "current", object = CoCoObject); # FALSE
isSubmodel("current", "base", object = CoCoObject); # TRUE
isSubmodel("last", "base", object = CoCoObject); # TRUE

# Objects:

isSubmodel(fullModel, homogeneModel, object = CoCoObject); # FALSE
isSubmodel(homogeneModel, fullModel, object = CoCoObject); # TRUE

# Non existing models:

isSubmodel("current", 7, object = CoCoObject); # NULL
isSubmodel(7, "base", object = CoCoObject); # NULL

makeCurrent(7, object = CoCoObject);
isSubmodel(1, 4, object = CoCoObject); # FALSE
isSubmodel(4, 1, object = CoCoObject); # TRUE

showModel("all", object = CoCoObject);

makeCurrent(4, object = CoCoObject);
isSubmodel("next", "base", object = CoCoObject); # Using current!
isSubmodel("previous", "base", object = CoCoObject); #  Using current!

# Text string with generating class:

isSubmodel("aby", object = CoCoObject); # TRUE
isSubmodel("ab", "a,b", object = CoCoObject); # FALSE

enterModel("ab", object = CoCoObject);
isSubmodel("aby", object = CoCoObject); # TRUE: Sub model of base!!!!
makeBase(, object = CoCoObject);
isSubmodel("aby", object = CoCoObject); # FALSE

endCoCo(object = CoCoObject);
}
\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{makeCurrent}
\alias{makeCurrent}
\alias{makeBase}

\title{ Move the pointer named CURRENT (BASE) in the CoCo object }

\description{
   Move the internal pointer named CURRENT (BASE)
   in the list of models in the CoCo object.
   Values returned from models are by default of the CURRENT model.
   By default, the CURRENT model is tested against the BASE model.
}

\usage{
makeCurrent(model = "last", silent = TRUE, both = FALSE, push = FALSE,
	   data = NULL, object = .object.of.model(model, 
                                                  data = data, ...), ...)
makeBase(model = "current", silent = TRUE, both = FALSE, push = FALSE,
	 data = NULL, object = .object.of.model(model, 
                                                data = data, ...), ...)
}

\arguments{
  \item{model}{ Numeric, text string, or model object.
	 If numeric then the CURRENT (BASE) pointer is moved to 
	 the model with that number (if the model is available).
	 The model number is then returned. 
         The text strings \code{"base"}, \code{"current"}, \code{"last"},
         \code{"previous"}, and \code{"next"} will
	 cause the model pointer to be moved to respectively the BASE model,
	 the CURRENT model, the LAST model (model the largest number),
	 the model with the largest number smaller
         then the number of the CURRENT (BASE) model, and finally
	 the model with the smallest number larger
         then the number of the CURRENT (BASE) model.
	 }
  \item{silent}{ Logical: If FALSE then some error messages are printed
		 when the model is not available. }
  \item{both}{ Logical: 
               If \code{both} is TRUE then both pointers 
	       (CURRENT and BASE) are moved (in CoCoCg):
               For \code{"next"} and \code{"previous"} first the CURRENT (BASE) model
	       of the call is set, and then the other pointer BASE (CURRENT)
	       are moved to the same model. }
  \item{push}{ Logical: 
               If \code{push} is TRUE then both pointers are pushed onto
	       a stack internally in the CoCoCg object - with the ability
	       to restore the pointers by, e.g., the \code{pop} argument to
               \code{\link{returnModelNumber}}. }
  \item{data}{ ( See \code{\link{exportCoCo}}. ) }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ ( Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. ) }
}

\details{
 The model first entered into a CoCo object is
 both BASE and CURRENT, and is given the number 1.
 The BASE (first) model stays BASE until another model is declared as BASE.
 Additional entered models, models created by \code{\link{editModel}}
 and models selected in steps of \code{\link{backward}}
 and \code{\link{forward}} are given an increasing number,
 and inserted into the model list.
 The model last entered is the CURRENT model.
 The last model generated by \code{\link{editModel}} or
 selected in steps of \code{\link{backward}} or \code{\link{forward}}
 is the LAST model, and can be named CURRENT by 
 \code{makeCurrent(model = "last", ...)}.
}

\value{
  The logical FALSE is returned, if the model is not available,
  else an integer is returned. If the model argument is an integer or
  a model object then the model number is returned.
}

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ \code{both} and \code{push} is only implemented for CoCoCg objects. 

\code{makeCurrent(model = "previous", ...)} 
at the first model will return FALSE,
but \code{makeCurrent(model = "next", ...)} at the last model 
will set the CURRENT to the first model in the model list, 
and return an integer.

\code{makeCurrent} will not accept a text string with the generating class
of a model as an argument.
(\code{makeCurrent} without a CoCo object is irrelevant. )

}

\seealso{\code{\link{enterModel}}, \code{\link{showModel}},
         \code{\link{returnTest}},
         \code{\link{isSubmodel}}, \code{\link{propertyModel}}, 
         \code{\link{returnModel}} and \code{\link{returnModelNumber}}. }

\examples{
library(CoCo);
data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);

# Enter the saturated model:	
enterModel("*", object = CoCoObject);

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, 
         follow = TRUE, object = CoCoObject);

# Show the model list:
showModel("all", object = CoCoObject);

# Test the last model against the saturated model (the first model):
makeCurrent("last", object = CoCoObject);
showTest(object = CoCoObject);

# "last" is default for makeCurrent:
showModel("all", object = CoCoObject);
makeCurrent(object = CoCoObject);
showModel("all", object = CoCoObject);

# "current" is default for makeBase:
makeBase(object = CoCoObject);
showModel("all", object = CoCoObject);
makeBase("current", object = CoCoObject);
showModel("all", object = CoCoObject);

# Generate some more models, here by "editModel":
	
# enterModel("ADEF,ABDG.;", object = CoCoObject);
enterModel("ACDE,ABCF.;", object = CoCoObject);
makeBase(object = CoCoObject);

editModel(action = "drop.interactions", modification = "ABDG.;",
          object = CoCoObject);
makeCurrent("last", object = CoCoObject);
showTest(object = CoCoObject);

editModel(action = "drop.edges", modification = "AD,BG.;",
          object = CoCoObject);
makeCurrent("last", object = CoCoObject);
showTest(object = CoCoObject);

# enterModel("ADF,AEF,BD,G.;", object = CoCoObject);
enterModel("ACE,ADE,BC,F.;", object = CoCoObject);
makeCurrent("last", object = CoCoObject);
showTest(object = CoCoObject);

enterModel(".;", object = CoCoObject);

showModel("all", object = CoCoObject);

makeBase(2, object = CoCoObject);
makeCurrent(6, object = CoCoObject);

showModel("all", object = CoCoObject);
	
# Show the first 10 models:
makeCurrent(10, object = CoCoObject)
while(makeCurrent("previous", 
                  object = CoCoObject)) showModel(object = CoCoObject)

# Show the first 10 models:
makeCurrent(10, object = CoCoObject)
while(returnModelNumber("current", object = CoCoObject) < 15) {
	 makeCurrent("next", object = CoCoObject); 
	 showModel(object = CoCoObject); }

endCoCo(object = CoCoObject);
}
\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{numberVariates}
\alias{numberVariates}

\title{ The number of variables in the CoCo object }

\description{ Return the number of variables entered into the CoCo object. }

\usage{
numberVariates(full = FALSE, data = NULL, 
               object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{full}{ Logical, if \code{full} is TRUE then the number
	       of specified variables is returned, that is
	       number without \code{\link{setUseVariables}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ Numeric }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{setUseVariables}} and \code{\link{showOptions}}. }

\examples{ 
library(CoCo);
data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);
numberVariates(object = CoCoObject);

Specification <- returnVariableDescription(object = CoCoObject);
setUseVariables(paste(Specification[[1]][c(1,3,4,6)], collapse = ""),
                object = CoCoObject);
enterTable(c(Reinis), object = CoCoObject);

numberVariates(object = CoCoObject);
numberVariates(full = TRUE, object = CoCoObject);

showOptions("specification", object = CoCoObject);

endCoCo(object = CoCoObject);

# - - - - -  - - - - -  - - - - -  - - - - -  - - - - -  - - - - -  - - - - - #

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);

numberVariates(object = CoCoObject);
numberVariates(full = TRUE, object = CoCoObject);

endCoCo(object = CoCoObject);

# - - - - -  - - - - -  - - - - -  - - - - -  - - - - -  - - - - -  - - - - - #

library(CoCo);
data(Byssinosis38);
CoCoObject <- makeCoCo();
enterTable(Byssinosis38, object = CoCoObject);

numberVariates(object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{optionsCoCo}
\alias{optionsCoCo}

\title{ Options settings for CoCo objects }
\description{
     Allow the user to set and examine a variety of "options" for each CoCo
     object which affect the way in which CoCo and CoCoCg computes and
     displays its results. 
}

\usage{
optionsCoCo(..., section = "all", status = FALSE, force.files = FALSE,
            data = NULL, object = .object.of.thing(data = data))
}

\arguments{
  \item{\dots}{ Any options can be defined, using 'name = value',
		similar to \code{\link{options}}.
                Further, 'options('name') == options()['name']', see the
		example.
                Those from the section \code{"cg"} are only avaliable in CoCoCg.
		}
  \item{section}{ The character string \code{"formats"}, \code{"tests"}, 
                  \code{"ips"}, \code{"cg"}, \code{"em"},
                  \code{"exact"}, \code{"other"}, or \code{"files"}. }
  \item{status}{ Logical, if \code{status} is TRUE, then the options
		 values are also print on standard output.  }
  \item{force.files}{ Logical. If \code{section} is \code{"all"} (default),
		      then the options for files (names, etc.) are only
		      returned if \code{force.files} is set to TRUE.
		      ( You do not want to share file names between 
			CoCo objects. )
		      }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
}

\details{ }

\value{A list with the following items: 

  \item{width                        }{int 127}
  \item{height                       }{int 65}
  \item{... }
  \item{warnings                     }{logi TRUE}

}

\section{Formats}{ 
	\itemize{
  \item{width                        }{int 127}
  \item{height                       }{int 65}
  \item{digits.table                 }{int 10}
  \item{decimals.table.probabilities }{int 6}
  \item{decimals.table.expected      }{int 2}
  \item{decimals.table.residual      }{int 4}
  \item{digits.test.statistics       }{int 9}
  \item{decimals.test.statistics     }{int 4}
  \item{digits.test.pvalues          }{int 7}
  \item{decimals.test.pvalues        }{int 5}
  \item{digits                       }{int 10}
  \item{decimals                     }{int 4}
  \item{pausing.of.output            }{logi FALSE}
  \item{n.lines                      }{int 22}
  \item{short.test.output            }{logi FALSE}
}
}

\section{Tests}{ 
	\itemize{
  \item{algorithm                    }{chr "c": "a", "b" or "c"}
  \item{partitioning                 }{logi TRUE}
  \item{adjusted.df                  }{logi TRUE}
  \item{power.lambda                 }{num 1}
  \item{ic                           }{logi FALSE}
  \item{bic                          }{logi FALSE}
  \item{ic.kappa                     }{num 3}
  \item{decomposable.mode            }{logi FALSE}
  \item{search.statistic             }{chr "deviance": "deviance", 
						       "power", or "chisq"}
  \item{acceptance.limit             }{num 0.05}
  \item{rejection.limit              }{num 0.05}
  \item{components.limit             }{num 2}
  \item{separators.limit             }{num 2}
  \item{reuse.tests                  }{logi TRUE}
}
}

\section{Ips}{ 
	\itemize{
  \item{ips.criterion                }{chr "cell": "cell" or "sum"}
  \item{ips.algorithm                }{chr "normal": "normal", "arithmetic", 
						     "geometric", or "harmonic"}
  \item{ips.number.of.iterations     }{int 100}
  \item{ips.epsilon                  }{num 1e-07}
}
}

\section{Cips}{ 
	\itemize{
  \item{cips.criterion               }{chr "cell": "cell" or "sum"}
  \item{cips.cycles                  }{int 100}
  \item{cips.epsilon                 }{num 1e-07}
}
}

\section{Cg}{ 
	\itemize{
  \item{mixed.criterion              }{chr "rell": "cell", "sum",
						   "suff", or "rell"}
  \item{mixed.cycles                 }{int 2000}
  \item{mixed.epsilon                }{num 1e-04}
  \item{mixed.init.epsilon           }{num 0.001}
  \item{mixed.log.l.round.error      }{num 1e-05}
  \item{mixed.random.noise           }{num 1e-04}
  \item{mixed.min.lambda             }{num 0.001}
  \item{cholesky.epsilon             }{num 1e-04}
}
}

\section{Em}{ 
	\itemize{
  \item{em                           }{logi FALSE}
  \item{em.number.of.iterations      }{int 100}
  \item{em.epsilon                   }{num 1e-07}
  \item{em.initial                   }{chr "uniform": "uniform", "first", 
						      "last", "mean", 
						      "random", or "input"}
}
}

\section{Exact}{ 
	\itemize{
  \item{exact.test                   }{chr "off": "off", "flop", "on", 
						  "all", or "deviance"}
  \item{exact.epsilon                }{num 1e-07}
  \item{exact.test.joined.test       }{logi TRUE}
  \item{exact.test.components        }{logi TRUE}
  \item{exact.test.unparted.test     }{logi TRUE}
  \item{exact.test.only.for.log.l    }{logi TRUE}
  \item{exact.number.of.tables       }{int 1000}
  \item{exact.list                   }{int [1:7] 20 2 1000 8 100 20 20}
  \item{exact.asymptotic             }{num 2}
  \item{fast                         }{logi TRUE}
  \item{exact.seed                   }{int 0}
}
}

\section{Other}{ 
	\itemize{
  \item{graph.mode                   }{logi FALSE}
  \item{report                       }{logi FALSE}
  \item{trace                        }{logi FALSE}
  \item{debug                        }{logi FALSE}
  \item{timer                        }{logi FALSE}
  \item{echo                         }{logi FALSE}
  \item{note                         }{logi FALSE}
  \item{sorted                       }{logi FALSE}
  \item{large                        }{logi FALSE}
  \item{huge                         }{logi TRUE}
  \item{graphical.search             }{logi TRUE}
  \item{warnings                     }{logi TRUE}
}
}

\section{Files}{ 
	\itemize{
  \item{diary                   }{logi FALSE}
  \item{diary.name              }{chr "/home/jhb/CoCo.diary.001.tmp"}
  \item{keep.diary              }{logi FALSE}
  \item{dump                    }{logi FALSE}
  \item{dump.name               }{chr ""}
  \item{keep.dump               }{logi FALSE}
  \item{report                  }{logi FALSE}
  \item{report.name             }{chr "/home/jhb/CoCo.report.003.tmp"}
  \item{keep.report             }{logi FALSE}
  \item{log                     }{logi TRUE}
  \item{log.name                }{chr "/home/jhb/CoCo.log.002.tmp"}
  \item{keep.log                }{logi FALSE}
  \item{log.data                }{logi TRUE}
}
}

%{}

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\seealso{ \code{\link{options}} and \code{\link{showOptions}}. }

\examples{
library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();

old.options <- optionsCoCo();

enterDataFrame(Rats, object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{partialAssociations}
\alias{partialAssociations}

\title{ Show partial associations }

\description{ Print on standard output the two dimensional tables with margins,
	      possible for each configuration in the cross classification
	      of other variables, and compute the measures of partial
	      associations on these tables. }

\usage{
partialAssociations(a = "", b = "", c = "", options, data = NULL, 
                    object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{a}{ A character string with the name of first variable. }
  \item{b}{ A character string with the name of second variable. }
  \item{c}{ A character string with the names of variables
	    to condition on. }
  \item{options}{ A character string with \code{options},
		  currently not used. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

\details{
	\itemize{

	\item{             Fisher's exact test }{:}  

	\item{                Pearson X.2 test }{:}  
	\item{       G.2 likelihood ratio test }{:}  
	\item{             Continuity-adj. X.2 }{:}  
	\item{             Yates corrected X.2 }{:}  
	\item{        McNemar test of symmetry }{:}  
	\item{                      Cramer's V }{:}  
	\item{                             Phi }{:}  
	\item{                         Max Phi }{:}  
	\item{       Contingency Coefficient C }{:}  
	\item{           Max Contingency coef. }{:}  
	\item{       Cross-product ratio alpha }{:}  
	\item{      Mantel-Haenszel chi-square }{:}  

	\item{         Pearson (product) corr. }{:}  
	\item{       Spearman rank corr. coef. }{:}  
	\item{         Ln(Cross-product ratio) }{:}  
	\item{                        Yule's Q }{:}  
	\item{                        Yule's Y }{:}  
	\item{                        Gamma, G }{:}  
	\item{                 Kendall's Tau b }{:}  
	\item{                  Stuart's Tau c }{:}  
	\item{                  Somers' D, R|C }{:}  
	\item{                  Somers' D, C|R }{:}  
	\item{      Goodman-Kruskal's Tau, R|C }{:}  
	\item{      Goodman-Kruskal's Tau, C|R }{:}  
	\item{       Optimal pred. lambda, R|C }{:}  
	\item{       Optimal pred. lambda, C|R }{:}  
	\item{       Optimal pred. lambda, sym }{:}  
	\item{       Optimal pred. lambda* R|C }{:}  
	\item{       Optimal pred. lambda* C|R }{:}  
	\item{        Uncertainty coef. U, R|C }{:}  
	\item{        Uncertainty coef. U, C|R }{:}  
	\item{        Uncertainty coef. U, sym }{:}  
	\item{                           Kappa }{:}  
 %	\item{                           Kappa }{:}  

	}
 }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{showTest}}. }

\examples{
library(CoCo);
data(HairEyeColor);
CoCoObject <- makeCoCo();
enterTable(HairEyeColor, object = CoCoObject);

partialAssociations(":Hair:Eye", object = CoCoObject);
partialAssociations(":Hair", ":Eye", object = CoCoObject);
partialAssociations(":Hair", ":Eye", ":Sex", object = CoCoObject);

endCoCo(object = CoCoObject);

# - - - - -  - - - - -  - - - - -  - - - - -  - - - - -  - - - - -  - - - - - #

library(CoCo);
data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);
partialAssociations("AB", object = CoCoObject);

setOrdinal("AB", object = CoCoObject);
partialAssociations("AB", object = CoCoObject);

# Get Fisher's EXACT test when the total count of the sub table
# is less than 1000:

partialAssociations("A", "B", "F", object = CoCoObject);

endCoCo(object = CoCoObject);

}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{propertyModel}
\alias{propertyModel}

\title{ Ask a query for a model }

\description{ Test a query for a model. }

\usage{
propertyModel(query = "chordal", model = FALSE, 
              prior.action = NULL, modification = NULL, data = NULL, 
              object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{query}{ A character string. The argument \code{query} is
		\code{"graphical"}, 
		\code{"decomposable"}, (or \code{"chordal"}, 
		                            \code{"triangulated"}, 
                                        or \code{"rigid.circuit"}),
		\code{"tree"}, 
		\code{"connected"}, 
		\code{"undirected"} (or \code{"skeleton"}),
		\code{"moral"}, 
		\code{"acyclic"}, 
		\code{"MIM-model"}, 
		\code{"mean-linear"}, 
		\code{"d-collapsible"}, 
		\code{"q-equivalent"}, 
		\code{"homogeneous"}, 
		\code{"full-specified"}, 
		\code{"degenerated"}, 
		\code{"discrete"} (or \code{"pure-discrete"}),
		\code{"continuous"} (or \code{"pure-continuous"}),
		\code{"mixed"}, 
		or \code{"regression"} (or \code{"cg-regression"}).
		}

  \item{model}{ See \code{\link{returnModel}}. }

  \item{prior.action}{ A character string,
		       if \code{prior.action} is set, then
		       the model is modified by this action before
		       asking the query. See \code{\link{editModel}}. }
  \item{modification}{ See \code{\link{editModel}}. }

  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}


\details{
    \itemize{
	\item{ Graphical }{:} 
	\item{ Decomposable }{ (or \code{"chordal"}, \code{"triangulated"},
                                or \code{"rigid.circuit"}): }
	\item{ Tree }{:} 
	\item{ Connected }{:} 
	\item{ Undirected }{ (or \code{"skeleton"}): }
	\item{ Moral }{:} 
	\item{ Acyclic }{:} 
	\item{ MIM-model }{:} 
	\item{ Degenerated }{:} 
	\item{ Mean-linear }{:} 
	\item{ D-collapsible }{:} 
	\item{ Q-equivalent }{:} 
	\item{ Homogeneous }{:} 
	\item{ Full-specified }{:} 
	\item{ Discrete }{ (or \code{"pure-discrete"}): }
	\item{ Continuous }{ (or \code{"pure-continuous"}): }
	\item{ Mixed }{ (or \code{"regression"} or \code{"cg-regression"}): }
    }
 }

\value{ Logical. }

% \references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
%             ( http://www.jstatsoft.org/v06/i04/ )
%             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

\seealso{ \code{\link{propertySet}}. }

\examples{
library(CoCo);
data(Fuchs82);
CoCoObject <- makeCoCo();
enterTable(Fuchs82, object = CoCoObject);

enterModel("mdp,da,am,dg,gs,sa", object = CoCoObject);

propertyModel("graphical", object = CoCoObject);
propertyModel("decomposable", object = CoCoObject);
propertyModel("connected", object = CoCoObject);
propertyModel("tree", object = CoCoObject);

enterModel("*", object = CoCoObject);
backward(recursive = TRUE, follow = TRUE, object = CoCoObject);
makeCurrent("last", object = CoCoObject);
showModel("all", object = CoCoObject);
propertyModel("graphical", object = CoCoObject);
propertyModel("decomposable", object = CoCoObject);
propertyModel("connected", object = CoCoObject);
propertyModel("tree", object = CoCoObject);

editModel("drop.edges", "md", object = CoCoObject);
makeCurrent("last", object = CoCoObject);
showModel("all", object = CoCoObject);
propertyModel("graphical", object = CoCoObject);
propertyModel("decomposable", object = CoCoObject);
propertyModel("connected", object = CoCoObject);
propertyModel("tree", object = CoCoObject);

endCoCo(CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{propertySet}
\alias{propertySet}

\title{ Ask a query for a set of variables }

\description{ Test a query for a subset of the variables of a model. }

\usage{
propertySet(query = "in.one.clique", set = "", set.a = "", set.b = "", 
            model = FALSE, prior.action = NULL, 
            modification = NULL, data = NULL, 
            object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{query}{ A character string with the \code{query}:
		\code{"is.separator"}, 
		\code{"is.d-separator"}, 
		or \code{"in.one.clique"}. }
  \item{set}{ A character string: 
	      Test whether \code{set} is in one and only one clique
	      or a separator according to the argument \code{query}. }
  \item{set.a}{ A character string:
		If \code{query} is 
		\code{"is.separator"} or \code{"is.d-separator"}
		and \code{set.a} and \code{set.b} are given,
		then it is tested whether \code{set} separates
		\code{set.a} and \code{set.b} in the model. }
  \item{set.b}{ A character string:  See argument \code{set.a}. }

  \item{model}{ See \code{\link{returnModel}}. }

  \item{prior.action}{ A character string,
		       if \code{prior.action} is set, then
		       the model is modified by this action before
		       asking the query. See \code{\link{editModel}}. }
  \item{modification}{ See \code{\link{editModel}}. }

  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

\details{
    \itemize{
	\item{ In one clique }{:} 
	\item{ Is separator }{: }
	\item{ Is d-separator }{: }
    }
 }

\value{ Logical }

% \references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
%             ( http://www.jstatsoft.org/v06/i04/ )
%             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

\seealso{ \code{\link{propertyModel}}. }

\examples{
library(CoCo);

data(Fuchs82);

CoCoObject <- makeCoCo();
enterTable(Fuchs82, object = CoCoObject);

enterModel("mdp,da,am,dg,gs,sa", object = CoCoObject);

propertySet("in.one.clique", set = "d,m.", object = CoCoObject);

propertySet(query = "separator", set = "ds.",  object = CoCoObject);
propertySet(query = "separator", set = "a.",   object = CoCoObject);
propertySet(query = "separator", set = "ag.",  object = CoCoObject);
propertySet(query = "separator", set = "adm.", object = CoCoObject);
propertySet(query = "separator", set = "am.",  object = CoCoObject);
propertySet(query = "separator", set = "dm.",  object = CoCoObject);

returnSets(model = FALSE, type = "is.separator", set = "dm.",
           object = CoCoObject); 

propertySet(query = "separator", set = "d.", 
            set.a = "dpm", set.b = "gsa", object = CoCoObject);
propertySet(query = "separator", set = "da.",
            set.a = "dpm", set.b = "gs",  object = CoCoObject);
propertySet(query = "separator", set = "da.",
            set.a = "dpm", set.b = "gsa", object = CoCoObject);
propertySet(query = "separator", set = "dm.",
            set.a = "dpm", set.b = "gsa", object = CoCoObject);
propertySet(query = "separator", set = "ds.", set.a = "dpm", set.b = "ga");

enterModel("gasd,adm,dpm.;", object = CoCoObject);

propertySet("in.one.clique", set = "d,s.", object = CoCoObject);
propertySet("in.one.clique", set = "d,m.", object = CoCoObject);
propertySet("in.one.clique", set = "s,p.", object = CoCoObject);

endCoCo(CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{randomTableReplacement}
\alias{randomTableReplacement}

\title{ Replace the table of counts
	 with a random table with margins unchanged }

\description{ Replace the table observed counts with random table of counts
	      but with counts as the counts of the sufficient tables for the
	      decomposable model. }

\usage{
randomTableReplacement(model = "current", data = NULL, 
                       object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{returnModel}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{enterDataFrame}}. }

\examples{ 
library(CoCo);
data(HairEyeColor);
CoCoObject <- makeCoCo();
enterTable(HairEyeColor, object = CoCoObject);
enterModel(":Hair:Sex,:Eye:Sex", object = CoCoObject);
returnTable("observed", "*", object = CoCoObject);
returnTable("observed", ":Hair:Sex", object = CoCoObject);
returnTable("observed", ":Eye:Sex", object = CoCoObject);

randomTableReplacement(object = CoCoObject);
returnTable("observed", "*", object = CoCoObject);
returnTable("observed", ":Hair:Sex", object = CoCoObject);
returnTable("observed", ":Eye:Sex", object = CoCoObject);

randomTableReplacement(object = CoCoObject);
returnTable("observed", "*", object = CoCoObject);
returnTable("observed", ":Hair:Sex", object = CoCoObject);
returnTable("observed", ":Eye:Sex", object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnDeviance}
\alias{returnDeviance}
\title{ Return likelihoods, deviance, dimensions, etc. }
\description{
  Returns the test statistics (deviance and F-test statistics) with p-values
  based on the likelihoods and the dimensions of the two argument models.
  For discrete models also an adjustment of the degrees of freedom
  is returned.
}
\usage{
returnDeviance(model.1 = "current", model.2 = "base", data = NULL, 
               object = .object.of.models(model.1, model.2, 
                                          data = data, ...), ...)
}
\arguments{
  \item{model.1}{ See \code{\link{isSubmodel}}. 
  % If both model arguments are the default value FALSE,
  % then the BASE model will be used for both models.
  % If \code{model.2} is set different from FALSE then the default value
  % of \code{model.1} is "current" model.
  }
  \item{model.2}{ See \code{\link{isSubmodel}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{A labeled vector of reals. }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ A vector of zeros is returned if an error occurs.
       \code{\link{returnTest}} will return NULL
       if the models are not available or nested.
       % Note that when FALSE (default) is given for both models,
       % the "base" will be used for both models. 
}

\seealso{\code{\link{enterModel}}, \code{\link[CoCoObjects]{makeModel}},
         \code{\link{showModel}}, \code{\link{makeCurrent}},
         \code{\link{returnModel}}, \code{\link{returnModelNumber}},
         \code{\link{partialAssociations}}, \code{\link{optionsCoCo}},
         \code{\link{showTest}}, \code{\link{showDeviance}},
         \code{\link{returnTest}}, 
         \code{\link{backward}} and \code{\link{forward}}. }

\examples{ 

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

# ( Should be replaced by calculation of the tests of David Edwards book. )

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, 
         follow = TRUE, object = CoCoObject);

# Show the model list:
showModel("all", object = CoCoObject);

returnDeviance("last", 1, object = CoCoObject);

homogeneModel <- makeModel(enterModel("[[ab]] / [[aby][abx]] / [[x^][abxy][y^]]",
	                   object = CoCoObject));

returnDeviance("last", 1, object = CoCoObject);

endCoCo(object = CoCoObject);

}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnEdges}
\alias{returnEdges}
\title{ Return the indices of vertices of edges }

\description{ Return a matrix with the indices of the vertices of the edges.
	      The edges can be the edges of the model,
	      the edges not in the model,
	      or the model can be ignored
	      (and thus the edges are returned from the
	      saturated model according to the fixing of edges).
	      And the edges can be edges not fixed in the model,
	      edges fixed in the model,
	      or the fixing of edges can be ignored.
}

\usage{
returnEdges(model = "current", edges = "in.model", fix = FALSE, data = NULL,
            object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{returnModel}}. }
  \item{edges}{ Text string: \code{"in.model"}, 
		\code{"all"}, or \code{"not.in.model"}. 
		Default: \code{"in.model"}. }
  \item{fix}{ Text string:  \code{"fix.edges"}, 
	      \code{"ignore.fixing"} (ignore fixing of edges),
	      or \code{"not.fix.edges"}. 
	      Default: \code{"not.fix.edges"}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ A matrix of integers with the indices of the variables of the edges. }

\author{Jens Henrik Badsberg}

\note{ Fixing of edges is set by \code{\link{backward}},
       \code{\link{forward}}, and by \code{\link{ehForceFix}}.
}

\seealso{ \code{\link{backward}}, \code{\link{forward}},
	   \code{\link{eh}}, \code{\link{ehForceFix}},
           \code{\link{returnFix}} and \code{\link{showOptions}}. }

\examples{

library(CoCoCg);

# Without "data" require ending the CoCo object:

# returnEdges("ab,xy", data = "From.input", continuous = "xy");
# endCoCo();

# With CoCo object:

data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);

Base <- makeModel(enterModel("[[ab]] / [[ay][ax][bx]] / [[xy]]",
                              object = CoCoObject));

Current <- makeModel(enterModel("[[a][b]] / [[ay][ax][bx]] / [[xy]]",
                              object = CoCoObject));

showModel("all");

returnEdges(object = CoCoObject);

returnEdges("base",    object = CoCoObject); # Does not work ?!?
returnEdges(Base,      object = CoCoObject);
returnEdges(1,         object = CoCoObject);
returnEdges("current", object = CoCoObject);
returnEdges(Current,   object = CoCoObject);
returnEdges(4,         object = CoCoObject);
returnEdges("last",    object = CoCoObject);
returnEdges(8,         object = CoCoObject); # ?!?: Should return NULL!!!

returnEdges("ab",      object = CoCoObject);
returnEdges("xy",      object = CoCoObject);
returnEdges("axy",     object = CoCoObject);

backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, follow = TRUE, 
         fix.edges = "xy", object = CoCoObject);

# .fix.edges("xy", object = CoCoObject);

returnEdges(object = CoCoObject);

returnEdges(fix = "all",             object = CoCoObject);
returnEdges(fix = "fix.edges",       object = CoCoObject);
returnEdges(fix = "non.fix.edges",   object = CoCoObject);

returnEdges(edges = "all",           object = CoCoObject);
returnEdges(edges = "in.model",      object = CoCoObject);
returnEdges(edges = "not.in.model",  object = CoCoObject);

returnEdges(edges = "all",          fix = "all",           object = CoCoObject);
returnEdges(edges = "in.model",     fix = "all",           object = CoCoObject);
returnEdges(edges = "not.in.model", fix = "all",           object = CoCoObject);

returnEdges(edges = "all",          fix = "fix.edges",     object = CoCoObject);
returnEdges(edges = "in.model",     fix = "fix.edges",     object = CoCoObject);
returnEdges(edges = "not.in.model", fix = "fix.edges",     object = CoCoObject);

returnEdges(edges = "all",          fix = "non.fix.edges", object = CoCoObject);
returnEdges(edges = "in.model",     fix = "non.fix.edges", object = CoCoObject);
returnEdges(edges = "not.in.model", fix = "non.fix.edges", object = CoCoObject);

endCoCo(object = CoCoObject);

}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnExpression}
\alias{returnExpression}

\title{ Return the expression of the estimates of parameters }

\description{ Return closed form expression for the parameter estimates. }

\usage{
returnExpression(model = "current", type = "expression", 
		 omit.prime.components = FALSE, omit.separators = FALSE, 
		 omit.generators = FALSE, state.space = FALSE,
		 return.flags = FALSE, split.sets = FALSE, 
		 split.models = TRUE, split.generators = TRUE, 
		 eliminate.empty = TRUE, data = NULL, 
		 object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{returnModel}}. }
  \item{type}{ A character string:  \code{type} can be \code{"expression"}, 
	       \code{"prime.components"}, \code{"separators"}, 
               or \code{"junction.tree.components"}.
	       The type \code{"junction.-"}, \code{"tree.components"}
	       are only avaliable in CoCoCg objects.
    }
  \item{omit.prime.components}{ Logical, if \code{omit.prime.components} 
				is TRUE then prime components are omitted,
				only separators are returned. }
  \item{omit.separators}{ Logical, if \code{omit.separators} 
			  is TRUE then separators are omitted,
			  the prime components are returned. }
  \item{omit.generators}{ Logical, if \code{omit.generators} 
			  is TRUE then generators of non decomposable irreducible
			  components are omitted,
			  for non decomposable irreducible components
			  only the vertex sets are returned. }
  \item{state.space}{ Logical, if \code{state.space} 
		      is TRUE then variable sets of
		      irreducible components are returned. }
  \item{return.flags}{ Logical, if \code{return.flags} 
		       is TRUE then flags are return for each
		       irreducible component of mixed models.
		       Only for CoCoCg objects. 
		       See also \code{\link{returnJunctionTree}}. }
  \item{split.sets}{ Logical, if \code{split.sets} 
		     is TRUE then for mixed models the character strings for
		     variables in irreducible components and separators
		     are split into lists of variables.
		     Only for CoCoCg objects. 
		     See also \code{\link{returnJunctionTree}}. }
  \item{split.models}{ Logical, if \code{split.models} 
		       is TRUE then the character string with the mixed model
		       is split into 3 lists: discrete, linear and
		       quadratic generators.
		       Only for CoCoCg objects. 
		       See also \code{\link{returnJunctionTree}}. }
  \item{split.generators}{ Logical, if \code{split.generators} 
			   is TRUE then each generator of a mixed model
			   is split into a list of variables.
			   Only for CoCoCg objects. 
			   See also \code{\link{returnJunctionTree}}. }
  \item{eliminate.empty}{ Logical, if \code{eliminate.empty} 
			  is TRUE then empty sets are eliminated.
			  Only for CoCoCg objects. 
			  See also \code{\link{returnJunctionTree}}. }
  \item{data}{ ( See \code{\link{exportCoCo}}. ) }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ ( Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. ) }
}

% \details{ }

\value{
  For discrete model in CoCo, a list with
  \item{[[1]]}{A character string with complete components, separators and
	       non-decomposable irreducible components with generators, }
  \item{[[2]]}{A numeric vector with the indices of
               the complete components and separators, }
  \item{[[3]]}{A constant for the model depending on
               the discrete variables not in the model. }

 In CoCoCg ...
}

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

\seealso{ \code{\link{returnJunctionTree}}. }

\examples{
library(CoCo);
data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);

# Enter the saturated model:	
enterModel("*", object = CoCoObject);

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, follow = TRUE);

# Show the model list:
showModel("all", object = CoCoObject);

makeCurrent("last", object = CoCoObject);

returnExpression(object = CoCoObject);

str(returnExpression(type = "expression", object = CoCoObject));

str(returnExpression(omit.prime.components = TRUE, object = CoCoObject));
str(returnExpression(omit.separators = TRUE, object = CoCoObject));
str(returnExpression(omit.generators = TRUE, object = CoCoObject));

str(returnExpression(type = "separators", object = CoCoObject));
str(returnExpression(type = "prime.components", object = CoCoObject));

str(returnExpression(state.space = TRUE, object = CoCoObject)); # ?

endCoCo(CoCoObject);

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

enterModel("[[a][b]] / [[ay][ax][bx]] / [[xy]]", object = CoCoObject);

showModel("all", object = CoCoObject);

makeCurrent("last", object = CoCoObject);

returnExpression(object = CoCoObject);

str(returnExpression(type = "expression", object = CoCoObject));

str(returnExpression(omit.prime.components = TRUE, object = CoCoObject));
str(returnExpression(omit.separators = TRUE, object = CoCoObject));
str(returnExpression(omit.generators = TRUE, object = CoCoObject));

str(returnExpression(type = "separators", object = CoCoObject));
str(returnExpression(type = "prime.components", object = CoCoObject));

str(returnExpression(state.space = TRUE, object = CoCoObject)); # ?

str(returnExpression(return.flags = TRUE, object = CoCoObject));

str(returnExpression(split.sets = TRUE, object = CoCoObject)); # ?
str(returnExpression(eliminate.empty = FALSE, object = CoCoObject)); # ?

str(returnExpression(type = "junction.tree.components",
                     split.models = FALSE, object = CoCoObject));

str(returnExpression(type = "junction.tree.components",
                     split.generators = FALSE, object = CoCoObject));

endCoCo(CoCoObject);

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #

data(Fuchs82);

CoCoObject <- makeCoCo();
enterTable(Fuchs82, object = CoCoObject);

enterModel("mdp,da,am,dg,gs,sa", object = CoCoObject);


# State-space, with generators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = FALSE, state.space = TRUE, object = CoCoObject);

# State-space, without generators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = TRUE, state.space = TRUE, object = CoCoObject);

showFormula(object = CoCoObject);

# State-space, with generators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = FALSE, state.space = TRUE, object = CoCoObject);

# State-space, without generators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = TRUE, state.space = TRUE, object = CoCoObject);

# Expression:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = FALSE, state.space = FALSE, object = CoCoObject);

# Expression, without generators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = FALSE,
                 omit.generators = TRUE, state.space = FALSE, object = CoCoObject);

# Prime components:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = FALSE, omit.separators = TRUE,
                 omit.generators = TRUE, state.space = FALSE, object = CoCoObject);
returnExpression(model = FALSE, type = "prime.components", object = CoCoObject);

# Separators:
returnExpression(model = FALSE, type = "expression", 
                 omit.prime.components = TRUE, omit.separators = FALSE,
                 omit.generators = TRUE, state.space = FALSE, object = CoCoObject);
returnExpression(model = FALSE, type = "separators", object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnFix}
\alias{returnFix}

\title{ Return the edges fixed in model selection }

\description{
  Return the edges fixed
  (e.i. not considered for removal in the latest call of
  \code{\link{backward}}
   or not considered for entering in the latest call of
  \code{\link{forward}}),
  or edges banned or forced into the EH procedure by \code{\link{ehForceFix}}.
}

\usage{
returnFix(code = "edges", data = NULL, 
          object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{code}{ A text string with
	       \code{"edges"} (edges not considered for removal in the 
			       latest call of \code{\link{backward}}
			       or not considered for entering in the 
			       latest call of \code{\link{forward}}),
               \code{"in"} (edges forced into EH by
		     \code{ehForceFix("what", fix = "in", ...)}),
               or \code{"out"} (edges banned in EH by
		     \code{ehForceFix("what", fix = "out", ...)}).
		     }
  \item{data}{ ( See \code{\link{exportCoCo}}. ) }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ ( Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. ) }
}

% \details{ }

\value{ A text string with a generating class of the fixing. }

\author{Jens Henrik Badsberg}

\note{ Fixing of edges is set by \code{\link{backward}}, \code{\link{forward}},
       and \code{\link{ehForceFix}}.
}

\seealso{ \code{\link{forward}}, \code{\link{backward}},
	   \code{\link{eh}}, \code{\link{ehForceFix}},
           \code{\link{returnFix}} and \code{\link{showOptions}}. }

\examples{
library(CoCo);
data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);

# Enter the saturated model:	
enterModel("*", object = CoCoObject);

# Set a fixing of edges in "backward":

backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, follow = TRUE,
         fix.edges = "[[AB][EF]]", object = CoCoObject);

returnFix(object = CoCoObject);

ehForceFix("DE", fix = "in", object = CoCoObject)
ehForceFix("EF", fix = "out", object = CoCoObject)

returnFix("edges", object = CoCoObject);
returnFix("in",    object = CoCoObject);
returnFix("out",   object = CoCoObject);

eh(object = CoCoObject);

returnFix("edges", object = CoCoObject);
returnFix("in",    object = CoCoObject);
returnFix("out",   object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnJunctionTree}
\alias{returnJunctionTree}

\title{ Return the junction tree }

\description{ Return the junction tree. }

\usage{
returnJunctionTree(model = "current", type = "junction.tree.components",
		   omit.prime.components = FALSE, omit.separators = FALSE,
		   omit.generators = FALSE, state.space = FALSE,
		   return.flags = FALSE, split.sets = FALSE,
		   split.models = TRUE, split.generators = TRUE,
		   eliminate.empty = TRUE, data = NULL,
		   object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{returnModel}}. }
  \item{type}{ A character string: 
               \code{type} should be \code{"junction.tree.components"}. }
  \item{omit.prime.components}{ Logical, if \code{omit.prime.components} 
				is TRUE then prime components are omitted,
				only separators are returned. }
  \item{omit.separators}{ Logical, if \code{omit.separators} 
			  is TRUE then separators are omitted,
			  the prime components are returned. }
  \item{omit.generators}{ Logical, if \code{omit.generators} 
			  is TRUE then generators of non decomposable irreducible
			  components are omitted,
			  for non decomposable irreducible components
			  only the vertex sets are returned. }
  \item{state.space}{ Logical, if \code{state.space} 
		      is TRUE then variable sets of
		      irreducible components are returned. }
  \item{return.flags}{ Logical, if \code{return.flags} 
		       is TRUE then flags are return for each
		       irreducible component of mixed models. }
  \item{split.sets}{ Logical, if \code{split.sets} 
		     is TRUE then for mixed models the character strings for
		     variables in irreducible components and separators
		     are split into lists of variables. }
  \item{split.models}{ Logical, if \code{split.models} 
		       is TRUE then the character string with the mixed model
		       is split into 3 lists: discrete, linear and
		       quadratic generators. }
  \item{split.generators}{ Logical, if \code{split.generators} 
			   is TRUE then each generator of a mixed model
			   is split into a list of variables. }
  \item{eliminate.empty}{ Logical, if \code{eliminate.empty} 
			  is TRUE then empty sets are eliminated. }
  \item{data}{ ( See \code{\link{exportCoCo}}. ) }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ ( Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. ) }
}

% \details{ }

\value{ A tree structure with the junction tree. }


\author{Jens Henrik Badsberg}

\note{ The function is only available for CoCoCg objects. }

\seealso{ \code{\link{returnExpression}}. }

\examples{

  library(CoCoCg);
  data(Rats);
  CoCoObject <- makeCoCoCg();
  enterDataFrame(Rats, object = CoCoObject);
  fullModel <- makeModel(enterModel("*", object = CoCoObject));

  enterModel("[[a][b]] / [[ay][ax][bx]] / [[xy]]", object = CoCoObject);

  showModel("all", object = CoCoObject);

  makeCurrent("last", object = CoCoObject);

  str(returnJunctionTree(object = CoCoObject));

  str(returnJunctionTree(split.models = FALSE, object = CoCoObject));
  str(returnJunctionTree(split.generators = FALSE, object = CoCoObject));

  str(returnJunctionTree(omit.generators = TRUE, object = CoCoObject));
  str(returnJunctionTree(omit.generators = TRUE, split.sets = TRUE,
					  object = CoCoObject));

  str(returnJunctionTree(omit.separators = TRUE, split.models = FALSE, 
			 object = CoCoObject));

  str(returnJunctionTree(omit.separators = TRUE, split.models = FALSE, 
			 eliminate.empty = TRUE, object = CoCoObject)); # ?

  str(returnJunctionTree(omit.separators = TRUE, split.models = FALSE,
			 omit.generator = TRUE, object = CoCoObject));

  str(returnJunctionTree(omit.separators = TRUE, split.models = FALSE,
			 return.flags = TRUE,
			 omit.generator = TRUE, object = CoCoObject));

  str(returnJunctionTree(omit.separators = TRUE, split.models = FALSE,
			 return.flags = TRUE, state.space = TRUE,
			 omit.generator = TRUE, object = CoCoObject));

  endCoCo(CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnModel}
\alias{returnModel}

\title{ Return the model }

\description{ Return the model or parts of it as a generating class. }

\usage{
returnModel(model = "current", type = "both", as.edges = FALSE, 
            split.string = FALSE, split.generators = FALSE, data = NULL, 
            object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ Numeric, model object, text string, or logical.
	 A numeric should give a valid model number in the \code{object},
         see \code{\link{makeCurrent}} about the model list.
         The argument can also be a CoCo model object, see
         \code{\link[CoCoObjects]{makeModel}} about creating model objects.
         A text string can give the model as a generating class
	 (or generating classes in MIM-form for mixed models), see
         \code{\link{enterModel}} for the notation of models.
         The text strings \code{"base"}, \code{"current"}, or \code{"last"}
         refers to the three models.
         The default value \code{"current"} for the CURRENT model
         can also be given as the logical FALSE.
	 }
  \item{type}{ A character string, selecting
               \code{"gc"}: generating class(es),
	       \code{"cs"}: causal structure,
	       \code{"both"}: both the generating class(es) and
			      the causal structure,
	       \code{"discrete"}: discrete part of mixed models,
	       \code{"linear"}: linear part of mixed models,
	       and \code{"quadratic"}: quadratic part of mixed models.
	       }
  \item{as.edges}{ Logical, if \code{as.edges} is TRUE then the edges
		   of the model are returned. }
  \item{split.string}{ Logical, if \code{split.string} is TRUE
		       then the generating classes are split into 
		       character strings with the generators. }
  \item{split.generators}{ Logical, if \code{split.generators} is TRUE
		       then the generating classes are split into lists,
		       each item in the list a vector of character string
		       with the vertices of a generator. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{
	A character string, a vector of character strings,
	a list of vectors of character strings,
	or a matrix of integers.
}

\references{Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ Currently only the generating class can be returned by \code{as.edges}. }

\seealso{ \code{\link{returnEdges}}. }

\examples{
library(CoCoCg);

# Without "data" require ending the CoCo object:

# returnModel("abxy,bcyz", type = "linear", data = "From.input", continuous = "xyz");
# endCoCo();

# With CoCo a object:

data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

enterModel("[[b][a]] / [[by][bx][ay][ax]] / [[xy]]", object = CoCoObject);
enterModel("[[a][b]] / [[ay][ax][bx]] / [[xy]]", object = CoCoObject);

homogeneModel <- makeModel(enterModel("[[ab]] / [[aby][abx]] / [[x^][abxy][y^]]",
	                   object = CoCoObject));

# Show the model list:

showModel("all", object = CoCoObject);

returnModel(object = CoCoObject);

returnModel(type="discrete", object = CoCoObject);
returnModel(type="linear", object = CoCoObject);
returnModel(type="quadratic", object = CoCoObject);

returnModel(type="gc", object = CoCoObject);
returnModel(type="cs", object = CoCoObject);

returnModel(3, type="gc", object = CoCoObject);

returnModel(3, type="discrete", object = CoCoObject);
returnModel(3, type="linear", object = CoCoObject);
returnModel(3, type="quadratic", object = CoCoObject);

returnModel(3, object = CoCoObject, split.string = TRUE);
str(returnModel(3, object = CoCoObject, split.generators = TRUE));

returnModel(3, object = CoCoObject, as.edges = TRUE);
.fix.edges("xy")
returnModel(3, object = CoCoObject, as.edges = TRUE);
returnModel(3, object = CoCoObject, as.edges = TRUE, fix = "all");

returnModel("abx", type = "discrete", object = CoCoObject);
returnModel("a,bx", type = "discrete", object = CoCoObject);

endCoCo(object = CoCoObject);

}
\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnModelNumber}
\alias{returnModelNumber}

\title{ Return the number of the CURRENT, BASE, or the LAST model }

\description{
  Return the internal model number of the CURRENT, the BASE. or the LAST model
  in the CoCo object.
}

\usage{
returnModelNumber(model = FALSE, no.warnings = FALSE, pop = FALSE, data = NULL, 
		  object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ The text string \code{"base"},
                \code{"current"} or \code{"last"}. }
  \item{no.warnings}{ Logical, if \code{no.warnings} is set to TRUE then
	no warnings is given if the model is not available. }
  \item{pop}{ Logical: If \code{pop} is set to TRUE in CoCoCg
	then the CURRENT and BASE pointers are set to the top pointers
	of the stack of CURRENT and BASE pointers in the CoCo object,
        see \code{push} at \code{\link{makeCurrent}}. }
  \item{data}{ ( See \code{\link{exportCoCo}}. ) }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ ( Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. ) }
}

\value{ An integer with the model number, if the model is avaliable,
        else NULL. }

\references{Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ \code{pop} is only implemented for CoCoCg objects. }

\seealso{\code{\link{enterModel}}, \code{\link{showModel}},
         \code{\link{returnTest}},
         \code{\link{isSubmodel}}, \code{\link{propertyModel}}, 
         \code{\link{makeCurrent}} and \code{\link{returnModel}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnModelVariates}
\alias{returnModelVariates}

\title{ Return the variates of the model }

\description{ Return the variables of the model. }

\usage{
returnModelVariates(model = FALSE, as.string = TRUE, data = NULL,
                    object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{returnModel}}. }
  \item{as.string}{ Logical, if \code{as.string} is false then
		    a vector of integers is returned.
		    1 (0) for variables (not) in the model. }
  \item{data}{ ( See \code{\link{exportCoCo}}. ) }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ ( Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. ) }
}

% \details{ }

\value{
  A character string with the variates of the model,
  or a vector of integers,  1 (0) for variables (not) in the model.
}

\references{Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\seealso{ \code{\link{returnModel}}. }

\examples{
library(CoCoCg);

data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

enterModel("ab,by", object = CoCoObject);
enterModel("bx", object = CoCoObject);

returnModelVariates(1, object = CoCoObject);
returnModelVariates(object = CoCoObject);

returnModelVariates(1, as.string = FALSE, object = CoCoObject);
returnModelVariates(as.string = FALSE, object = CoCoObject);
returnModelVariates(3, as.string = FALSE, object = CoCoObject);

returnModelVariates("by", as.string = FALSE, object = CoCoObject);

endCoCo(object = CoCoObject);

}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnNcells}
\alias{returnNcells}

\title{ Return the number of cells in a table }

\description{
	Return the number of cells in the table formed by the cross
	classification according to a given set of discrete variables.
}

\usage{
returnNcells(set = "*", full = FALSE, total = FALSE, data = NULL, 
             object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{set}{ A character string with a set of discrete variables. }
  \item{full}{ Logical, if \code{full} is TRUE then
	       all specified variables (\code{\link{setUseVariables}})
	       are considered. }
  \item{total}{ Logical, if \code{total} is TRUE then
		 also missing levels (\code{\link{excludeMissing}})
		 are counted. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

\value{ An integer. }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\seealso{ \code{\link{enterNames}},
	  \code{\link{setUseVariables}} and \code{\link{excludeMissing}}. }

\examples{

library(CoCo)
data(Hochberg77)
ftable(Hochberg77, col.vars=4:6)

# Without "data" require ending the CoCo object:

# returnNcells(data = Hochberg77);
# endCoCo();

# With CoCo object:

CoCoObject <- makeCoCo();

enterTable(Hochberg77, missing = c(1, 1, 0, 0, 0, 0), object = CoCoObject);

showOptions("specification", object = CoCoObject)

returnNcells(object = CoCoObject);

# With only a subset:

missing <- c(1, 1, 0, 0, 0, 0);
enterNames(names(dimnames(Hochberg77)), 
           levels = dim(Hochberg77) - missing,
           missing = missing, CoCoObject);

setUseVariables("bcdef.", object = CoCoObject)

enterTable(c(Hochberg77), object = CoCoObject);

showOptions("specification", object = CoCoObject)

returnNcells(object = CoCoObject);

returnNcells(set = "abc", object = CoCoObject);

returnNcells(set = "bc.", full = FALSE, total = FALSE, object = CoCoObject);
returnNcells(set = "bc.", full = FALSE, total = TRUE,  object = CoCoObject);
returnNcells(set = "abc.", full = TRUE,  total = FALSE, object = CoCoObject);
returnNcells(set = "abc.", full = TRUE,  total = TRUE,  object = CoCoObject);

excludeMissing("in", set = "bc.", object = CoCoObject);

returnNcells(set = "bc.", full = FALSE, total = FALSE, object = CoCoObject);
returnNcells(set = "bc.", full = FALSE, total = TRUE,  object = CoCoObject);
returnNcells(set = "abc.", full = TRUE,  total = FALSE, object = CoCoObject);
returnNcells(set = "abc.", full = TRUE,  total = TRUE,  object = CoCoObject);

endCoCo(object = CoCoObject);

# With continuous:

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
returnNcells(set = "ab;", object = CoCoObject);
returnNcells(object = CoCoObject); 

endCoCo(object = CoCoObject);

}
\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnSets}
\alias{returnSets}

\title{ Return a specific subset of the variables  }

\description{ Return for a model
                     the connected component containing a specific set, 
		     connected components,  
		     prime components,  
		     junction tree components,  
		     chain components,  
		     ancestral set,  
		     shortest paths between two sets, 
		     cut sets, 
		     separators,  
		     D-separators,  
		     neighbours of a set, 
		     TRUE if s set is a separator, 
		     or TRUE if s set is a d-separator. }

\usage{
returnSets(model = FALSE, set = "", set.a = "", set.b = "", 
           u = "", v = "", type = "primes", 
           split.gc = FALSE, split.generators = FALSE, data = NULL, 
           object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{returnModel}}. }

  \item{set}{ A character string with a variable set. }
  \item{set.a}{ A character string with a variable set. }
  \item{set.b}{ A character string with a variable set. }
  \item{u}{ A character string with a single variable name. }
  \item{v}{ A character string with a single variable name. }
  \item{type}{ A character string with the text
		\code{"connected.component"} (\code{set} used),
		\code{"connected.components"}, 
		\code{"prime.components"}, 
		\code{"chain.components"}, 
		\code{"junction.tree.components"}, 
		\code{"ancestral.set"}, 
		\code{"shortest.paths"} (\code{u} and \code{v} used),
		\code{"cut.sets"} (\code{u} and \code{v} or
                                   \code{set.a} and \code{set.a} used),
		\code{"separators"}, 
		\code{"d-separators"}, 
		\code{"neighbours"}, (\code{set} used),
		\code{"is.separator"}, (\code{set} used),
		\code{"is.d-separator"}, (\code{set} used).
		}

  \item{split.gc}{ See \code{\link{returnModel}}. }
  \item{split.generators}{ See \code{\link{returnModel}}. }

  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }

}

\details{
    \itemize{
	\item{ Connected component }{: (\code{set} used) }
	\item{ Connected components }{:} 
	\item{ Prime components }{:} 
	\item{ Junction tree components }{:} 
	\item{ Chain components }{:} 
	\item{ Ancestral set }{:} 
	\item{ Shortest paths }{: (\code{u} and \code{v} used) }
	\item{ Cut sets }{: (\code{u} and \code{v} or \code{set.a} and \code{set.a} used) }
	\item{ Separators }{:} 
	\item{ D-separators }{:} 
	\item{ Neighbours }{: (\code{set} used) }
	\item{ Is separator }{: (\code{set} used) }
	\item{ Is d-separator }{: (\code{set} used) }
    }
 }

\value{A boolean, NULL,
       a list with the component \code{string} with a generating class,
       a list with vectors of character strings of variables,
       or a vector of character strings of sets of variable. }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

\section{ToDo}{Separators not returned from mixed models. }

\seealso{ \code{\link{propertySet}}, \code{\link{propertyModel}},
          and \code{\link{returnVertexOrder}}. }

\examples{
library(CoCo);
data(Fuchs82);

CoCoObject <- makeCoCo();
enterTable(Fuchs82, object = CoCoObject);

enterModel("mdp,da,am,dg,gs,sa", object = CoCoObject);

returnSets(model = "current", type = "connected.component", set = "dm",
           object = CoCoObject);
returnSets(model = "current", type = "connected.components", 
           object = CoCoObject);

returnSets(model = "current", type = "prime.components", 
           object = CoCoObject); 
returnExpression(type = "prime.components",
           object = CoCoObject);

returnSets(model = "current", type = "junction.tree.components", 
           object = CoCoObject);
returnSets(model = "current", type = "chain.components", 
           object = CoCoObject);
returnSets(model = "current", type = "ancestral.set", 
           object = CoCoObject);
returnSets(model = "current", type = "shortests.paths", u = "s", v = "p", 
           object = CoCoObject);
returnSets(model = "current", type = "cut.sets", u = "s", v = "p", 
           object = CoCoObject);
returnSets(model = "current", type = "cut.sets", set.a = "sg", set.b = "p",
           object = CoCoObject);
returnSets(model = "current", type = "separators", 
           object = CoCoObject);
returnSets(model = "current", type = "d-separators", 
           object = CoCoObject);
returnSets(model = "current", type = "neighbours", set = "dm", 
           object = CoCoObject);
returnSets(model = "current", type = "is.separator", set = "dm", 
           object = CoCoObject);
returnSets(model = "current", type = "is.d-separator", set = "dm", 
           object = CoCoObject);

returnModel(object = CoCoObject);

returnModel(split.generators = TRUE, object = CoCoObject);

returnSets(model = FALSE, type = "neighbours", set = c("d", "m"), 
           object = CoCoObject);

returnSets(model = FALSE, type = "neighbours", set = "dm", 
           object = CoCoObject);

returnSets(model = FALSE, type = "neighbours", set = "[dm]", 
           object = CoCoObject);

returnSets(model = "current", type = "separators", 
           split.gc = TRUE, object = CoCoObject);

returnSets(model = "current", type = "separators", 
           split.generator = TRUE, split.gc = TRUE, object = CoCoObject);

returnSets(model = "current", type = "separators", 
           split.generator = TRUE, object = CoCoObject); # ?

endCoCo(object = CoCoObject);

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
enterModel("ax,xb,y.", object = CoCoObject);

returnSets(model = "current", type = "connected.component", set = "ax",
           object = CoCoObject);
returnSets(model = "current", type = "connected.components", 
           object = CoCoObject);

returnSets(model = "current", type = "prime.components", 
           object = CoCoObject); 
returnExpression(type = "prime.components",
           object = CoCoObject);

returnSets(model = "current", type = "junction.tree.components", 
           object = CoCoObject);
returnSets(model = "current", type = "chain.components", 
           object = CoCoObject);
returnSets(model = "current", type = "ancestral.set", 
           object = CoCoObject);

returnSets(model = "current", type = "shortests.paths", u = "a", v = "b", 
           object = CoCoObject);
returnSets(model = "current", type = "cut.sets", u = "a", v = "b", 
           object = CoCoObject);
returnSets(model = "current", type = "cut.sets", set.a = "a", set.b = "b",
           object = CoCoObject);

returnSets(model = "current", type = "separators", 
           object = CoCoObject); # ?
returnSets(model = "current", type = "d-separators", 
           object = CoCoObject);
returnSets(model = "current", type = "neighbours", set = "x", 
           object = CoCoObject);
returnSets(model = "current", type = "is.separator", set = "x", 
           object = CoCoObject);
returnSets(model = "current", type = "is.d-separator", set = "x", 
           object = CoCoObject);

returnModel(object = CoCoObject);

returnModel(split.generators = TRUE, object = CoCoObject);

returnSets(model = FALSE, type = "neighbours", set = c("x", "b"), 
           object = CoCoObject);

returnSets(model = FALSE, type = "neighbours", set = "x", 
           object = CoCoObject);

returnSets(model = FALSE, type = "neighbours", set = "[x]", 
           object = CoCoObject);

returnSets(model = "current", type = "separators", 
           split.gc = TRUE, object = CoCoObject);

returnSets(model = "current", type = "separators", 
           split.generator = TRUE, split.gc = TRUE, object = CoCoObject);

returnSets(model = "current", type = "separators", 
           split.generator = TRUE, object = CoCoObject); # ?

returnSets(model = "current", type = "separators", 
           split.gc = TRUE, object = CoCoObject); # ?

returnSets(model = "current", type = "separators", 
           split.generator = TRUE, split.gc = TRUE, object = CoCoObject); # ?

returnSets(model = "current", type = "separators", 
           split.generator = TRUE, object = CoCoObject); # ?

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnTable}
\alias{returnTable}

\title{ Return the counts and fitted values of a marginal table }

\description{ Return the observed probabilities, counts, 
	      means, covariance matrix, canonical parameters,
	      fitted values, residuals, etc. of marginal tables. }

\usage{
returnTable(type = "observed", set = "*", model = FALSE, 
            random = FALSE, log.transformed = FALSE, complete = FALSE, 
            discrete.ordered = TRUE, dump = FALSE, label = TRUE, 
            split = TRUE, discrete.outer = TRUE, mixed = FALSE, data = NULL, 
            object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{type}{ See also \code{\link{showTable}}. 
	       For \code{set} with only discrete variables
	       the \code{type} \code{"sparse.table"} is avaliable
	       to return the cells of the table with count different
	       from zero.
	       For \code{set} with both discrete and continuous variables
	       the argument \code{type} should be
	       \code{"canonical"},
	       \code{"moment"},
	       \code{"raw"},
	       \code{"mk"},
	       or, \code{"ms"}.
	     }
  \item{set}{ See \code{\link{showTable}}. }
  \item{model}{ See \code{\link{returnModel}}. }
  \item{random}{ See \code{\link{showTable}}. }
  \item{log.transformed}{ See \code{\link{showTable}}. }
  \item{complete}{ See \code{\link{showTable}}. }
  \item{discrete.ordered}{ See \code{\link{showTable}}. }

  \item{dump}{ Logical. For \code{set} with only discrete variables.
	       If \code{dump} is TRUE and \code{dump} of
	       \code{\link{optionsCoCo}} also is TRUE
	       then the table is written to the dump file.  }

  \item{label}{ Logical, if \code{label} then labels
		are set on returned arrays. }
  \item{split}{ Logical, for the argument \code{type} 
		with both discrete and continuous variables:
		If \code{split} is TRUE then
		the returned quantities are split
		into the three parts
		discrete, linear and quadratic. }
  \item{discrete.outer}{ Logical,  for the argument \code{type} 
			 with both discrete and continuous variables:
			 If \code{discrete.outer} is FALSE then 
			 order of the discrete and the continuous
			 variables are permuted. }

  \item{mixed}{ See \code{\link{showTable}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{showTable}}. }

\examples{
library(CoCoCg);
data(fev);

fevCoCo <- makeCoCoCg();
result <- enterDataFrame(fev, object = fevCoCo);

enterModel("*;", object = fevCoCo);

showTable("observed", ":Sex:Smoker", object = fevCoCo);

showTable("canonical", ":Sex:Smoker:Age:FEV:Height", 
		       table = TRUE, object = fevCoCo);
showTable("canonical", ":Sex:Smoker:Age:FEV:Height", 
		       matrix = TRUE, object = fevCoCo);
showTable("canonical", ":Age:FEV:Height",            
		       matrix = TRUE, object = fevCoCo);

c1 <- returnTable("canonical", ":Sex:Smoker:Age:FEV:Height", 
                  label = FALSE, split = FALSE, object = fevCoCo);
c2 <- returnTable("canonical", ":Sex:Smoker:Age:FEV:Height", 
                  label = TRUE, object = fevCoCo);
c3 <- returnTable("canonical", ":Sex:Smoker:Age:FEV:Height", 
                  label = TRUE, split = FALSE, object = fevCoCo);
c4 <- returnTable("canonical", ":Sex:Smoker:Age:FEV:Height", 
                  label = TRUE, split = FALSE, 
                  discrete.outer = TRUE, object = fevCoCo);

returnTable("canonical", ":Sex:Smoker:Age:FEV:Height", label = TRUE);

returnTable("moment", ":Sex:Smoker:Age:Height", label = TRUE)$Mean;
returnTable("moment", ":Smoker:Age:Height", label = TRUE)$Mean;
returnTable("moment", ":Sex:Age:Height", label = TRUE)$Mean;

c4[,,1]
c4[1,1,]
c5 <- returnTable("canonical", ":Sex:Smoker:Age:FEV:Height", 
                  label = TRUE, split = TRUE, discrete.outer = FALSE, 
		  object = fevCoCo);
c6 <- returnTable("canonical", ":Sex:Smoker:Age:FEV:Height", 
                  label = TRUE, split = TRUE, discrete.outer = TRUE, 
		  object = fevCoCo);

showTable("moment", ":Sex:Smoker:Age:FEV:Height", 
		    matrix = TRUE, object = fevCoCo);

m1 <- returnTable("moment", ":Sex:Smoker:Age:FEV:Height", 
                  label = FALSE, split = FALSE, object = fevCoCo);
m2 <- returnTable("moment", ":Sex:Smoker:Age:FEV:Height", 
                  label = TRUE, object = fevCoCo);
m3 <- returnTable("moment", ":Sex:Smoker:Age:FEV:Height", 
                  label = TRUE, split = FALSE, object = fevCoCo);
m4 <- returnTable("moment", ":Sex:Smoker:Age:FEV:Height", 
                  label = TRUE, split = FALSE, 
                  discrete.outer = TRUE, object = fevCoCo);
m4[,,1]
m4[1,1,]
m5 <- returnTable("moment", ":Sex:Smoker:Age:FEV:Height", 
                  label = TRUE, split = TRUE, 
                  discrete.outer = FALSE, object = fevCoCo);
m6 <- returnTable("moment", ":Sex:Smoker:Age:FEV:Height", 
                  label = TRUE, split = TRUE, 
                  discrete.outer = TRUE, object = fevCoCo);

endCoCo(object = fevCoCo);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnTest}
\alias{returnTest}
\title{ Return the Pearson $\chi^2$, the power divergence, etc. }

\description{
 Return for discrete data
 the Pearson $\chi^2$, the power divergence, and the deviance,
 and for tests of two ordinal variable conditional independent
 given discrete also the Goodman and Kruskal's Gamma coefficient,
 and for mixed data the deviance and the F-test.
 For discrete data also exact p-values can be returned.
}

\usage{
returnTest(model.1 = "current", model.2 = "base", push.pop = FALSE, data = NULL, 
           object = .object.of.models(model.1, model.2, data = data, ...), ...)
}

\arguments{
  \item{model.1}{ See \code{\link{isSubmodel}}. 
  % If both model arguments are 
  % the default value FALSE, then the BASE model will be used for both models.
  % If \code{model.2} is set different from FALSE then the default value
  % of \code{model.1} is "current" model.
  }
  \item{model.2}{ See \code{\link{isSubmodel}}. }
  \item{push.pop}{ Logical, if \code{push.pop} is TRUE, both model arguments
		   are numeric and the object argument is a CoCoCg object
		   then model pointers are restored by less calls of CoCoCg. 
		   See also \code{\link{returnModelNumber}}
		   and \code{\link{makeCurrent}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{A labeled vector of reals, or NULL if the an error occur,
       e.g. the models are not available or not nested. }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ % Note that when FALSE (default) is given for both models,
       % the "base" will be used for both models. 

       % Something is wrong inversion 1.6.1 for \code{\link{showTest}},
       % \code{\link{returnTest}}, and \code{\link{backward}}:
       % Homogene models are produced in backward,
       % but tests are preformed as the models are inhomogene?

      }

\seealso{\code{\link{enterModel}}, \code{\link[CoCoObjects]{makeModel}},
         \code{\link{showModel}}, \code{\link{makeCurrent}},
         \code{\link{returnModel}}, \code{\link{returnModelNumber}},
         \code{\link{partialAssociations}}, \code{\link{optionsCoCo}},
         \code{\link{showTest}}, \code{\link{showDeviance}},
         \code{\link{returnDeviance}}, 
         \code{\link{backward}} and \code{\link{forward}}. }

\examples{
}
\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnVariableDescription}
\alias{returnVariableDescription}

\title{ Return the specification of the data in the CoCo object }

\description{ Return the specification of the data in the CoCo object
	      in form of variable names, number of levels,
	      number of levels marked as missing value and type of variable. }

\usage{
returnVariableDescription(full = FALSE, levels = TRUE, 
                          missing.levels = TRUE, data = NULL, 
                          object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{full}{ Logical, if \code{full} is TRUE then the number
	       of specified variables is returned, that is
	       number without \code{\link{setUseVariables}}. }
  \item{levels}{ Logical, if \code{levels} is TRUE
		 then return the number of levels. }
  \item{missing.levels}{ Logical, if \code{missing.levels}
			  is TRUE then return the number of levels
			  marked as missing. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{
  A list with the components
  \item{names         }{ chr  }
  \item{labels        }{ NULL }
  \item{types         }{ int  }
  \item{stratum       }{ NULL }
  \item{levels        }{ int  }
  \item{missing.levels}{ int  }
}

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{forward}}. }

\examples{ 
library(CoCo);
data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);

showOptions("specification", object = CoCoObject);
Specification <- returnVariableDescription(object = CoCoObject);
Specification

endCoCo(object = CoCoObject);

# - - - - -  - - - - -  - - - - -  - - - - -  - - - - -  - - - - -  - - - - - #

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);

numberVariates(object = CoCoObject);
numberVariates(full = TRUE, object = CoCoObject);

endCoCo(object = CoCoObject);

# - - - - -  - - - - -  - - - - -  - - - - -  - - - - -  - - - - -  - - - - - #

library(CoCo);
data(Byssinosis38);
CoCoObject <- makeCoCo();
enterTable(Byssinosis38, object = CoCoObject);

numberVariates(object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{returnVertexOrder}
\alias{returnVertexOrder}

\title{ Return vertex order }

\description{ Return vertex orderings, including MaxCard, LexM and paths. }

\usage{
returnVertexOrder(model = FALSE, invers.order = FALSE, default.order = TRUE,
                  max.card = FALSE, path.order = FALSE, sub.path = FALSE,
                  marked = paste(";"), u = "", v = "",
                  names = NULL, levels = NULL, to.factor = NULL,
                  discrete = NULL, continuous = NULL, data = NULL,
                  object = .object.of.model(model, data = data, names = names,
                                            levels = levels, to.factor = to.factor,
                                            discrete = discrete,
                                            continuous = continuous, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{returnModel}}. }

  \item{invers.order}{ Logical, if \code{invers.order} is TRUE
                       then . }
  \item{default.order}{ Logical, if \code{default.order} is TRUE
                       then . }
  \item{max.card}{ Logical, if \code{max.card} is TRUE
                       then . }
  \item{path.order}{ Logical, if \code{path.order} is TRUE
                       then . }
  \item{sub.path}{ Logical, if \code{sub.path} is TRUE
                       then . }
  \item{marked}{ A character string, \code{marked} 
                       then . }
  \item{u}{ A character string, \code{u} 
                       then . }
  \item{v}{ A character string, \code{v} 
                       then . }

  \item{names}{ A character string, 
		\code{names} ... }
  \item{levels}{ A vector of integers, 
		 \code{levels} ... }
  \item{to.factor}{ A vector of integers, 
		    \code{to.factor} ... }
  \item{discrete}{ A vector of integers or a character string, 
		   \code{discrete} ... }
  \item{continuous}{ A vector of integers or a character string,
		     \code{continuous} ... }

  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

\seealso{ ~~objects to See Also as \code{\link{coco.init}}, ~~~ }

\examples{
library(CoCoCg);

# Without "data" does not require ending the CoCo object:

# returnVertexOrder("ab,xy", continuous = "xy");

# With CoCo object:

data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);

# Enter the saturated model:	
enterModel("*", object = CoCoObject);

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, 
         follow = TRUE, object = CoCoObject);

# Show the model list:
showModel("all", object = CoCoObject);

n <- returnModelNumber("last", object = CoCoObject);
for (i in 1:n) {
  showFormula(i, object = CoCoObject);
  showVertexOrder(i, object = CoCoObject);
  print(returnVertexOrder(i, object = CoCoObject));
}

returnVertexOrder(9, object = CoCoObject);
returnVertexOrder(9, max.card = TRUE, object = CoCoObject);
returnVertexOrder(9, default.order = FALSE, max.card = TRUE, object = CoCoObject);
returnVertexOrder(9, default.order = FALSE, max.card = FALSE, object = CoCoObject);

returnVertexOrder(9, marked = "AB;", object = CoCoObject);
returnVertexOrder(9, marked = "EF;", object = CoCoObject);

returnVertexOrder(9, u = "B;", v = "F;", 
                  path.order = TRUE, sub.path = TRUE, object = CoCoObject);
returnVertexOrder(9, u = "C;", v = "F;", 
                  path.order = TRUE, sub.path = TRUE, object = CoCoObject);

endCoCo(CoCoObject);

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #

data(Fuchs82);

CoCoObject <- makeCoCo();
enterTable(Fuchs82, object = CoCoObject);

enterModel("mdp,da,am,dg,gs,sa", object = CoCoObject);

returnVertexOrder(model = "current", 
                  path.order = TRUE, marked = paste("pd"),
                  u = "m", v = "g", object = CoCoObject);

returnVertexOrder(model = "current", invers.order = TRUE,
                  path.order = TRUE, marked = paste("pd"),
                  u = "m", v = "g", object = CoCoObject);

returnVertexOrder(model = "current", sub.path = TRUE,
                  path.order = TRUE, marked = paste("pd"),
                  u = "m", v = "g", object = CoCoObject);

returnVertexOrder(model = "current", 
                  path.order = TRUE, marked = paste("adps"),
                  u = "m", v = "g", object = CoCoObject);

returnVertexOrder(model = "current", sub.path = TRUE,
                  path.order = TRUE, marked = paste("adps"),
                  u = "m", v = "g", object = CoCoObject);

returnVertexOrder(model = "current", 
                  path.order = TRUE, marked = paste("adms"),
                  u = "p", v = "g", object = CoCoObject);


returnVertexOrder(model = "current", sub.path = TRUE,
                  path.order = TRUE, marked = paste("adms"),
                  u = "p", v = "g", object = CoCoObject);

returnVertexOrder(model = "current", 
                  path.order = TRUE, marked = paste("adms"),
                  u = "g", v = "p", object = CoCoObject);


returnVertexOrder(model = "current", sub.path = TRUE,
                  path.order = TRUE, marked = paste("adms"),
                  u = "g", v = "p", object = CoCoObject); 


showVertexOrder();

# Default order:
VertexOrder <- returnVertexOrder(model = "current",
                                 invers.order = FALSE,
                                 object = CoCoObject); 
VertexOrder

# Default order, inverse:
InverseOrder <- returnVertexOrder(model = "current",
                                  invers.order = TRUE,
                                  object = CoCoObject); 
InverseOrder

# Lex order:
returnVertexOrder(model = "current", invers.order = FALSE,
                  default.order = FALSE,  max.card = FALSE,
                  object = CoCoObject); 

# Lex order, inverse:
returnVertexOrder(model = "current", invers.order = TRUE,
                  default.order = FALSE,  max.card = FALSE,
                  object = CoCoObject); 

# Max-card order:
returnVertexOrder(model = "current", invers.order = FALSE,
                  default.order = FALSE,  max.card = TRUE,
                  object = CoCoObject); 

# Max-card order, inverse:
returnVertexOrder(model = "current", invers.order = TRUE,
                  default.order = FALSE,  max.card = TRUE,
                  object = CoCoObject); 

##

# Marked order, default:
returnVertexOrder(model = "current", invers.order = FALSE,
                  marked = "g", object = CoCoObject); 

# Marked order, Lex:
returnVertexOrder(model = "current", invers.order = FALSE,
                  default.order = FALSE,  max.card = FALSE,
                  marked = "g", object = CoCoObject); 

# (Marked order), Max-card:
returnVertexOrder(model = "current", invers.order = FALSE,
                  default.order = FALSE,  max.card = TRUE,
                  marked = "g", object = CoCoObject); 

##

# Marked order, default:
returnVertexOrder(model = "current", invers.order = FALSE,
                  marked = "d", object = CoCoObject); 

# Marked order, Lex:
returnVertexOrder(model = "current", invers.order = FALSE,
                  default.order = FALSE,  max.card = FALSE,
                  marked = "d", object = CoCoObject); 

# (Marked order), Max-card:
returnVertexOrder(model = "current", invers.order = FALSE,
                  default.order = FALSE,  max.card = TRUE,
                  marked = "d", object = CoCoObject); 

##

# Marked order, default:
returnVertexOrder(model = "current", invers.order = FALSE,
                  marked = "p", object = CoCoObject); 

# Marked order, Lex:
returnVertexOrder(model = "current", invers.order = FALSE,
                  default.order = FALSE,  max.card = FALSE,
                  marked = "p", object = CoCoObject); 

# (Marked order), Max-card:
returnVertexOrder(model = "current", invers.order = FALSE,
                  default.order = FALSE,  max.card = TRUE,
                  marked = "p", object = CoCoObject); 

endCoCo(CoCoObject);

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, follow = TRUE,
         object = CoCoObject);

homogeneModel <- makeModel(enterModel("[[ab]] / [[aby][abx]] / [[x^][abxy][y^]]",
	                     object = CoCoObject));

enterModel("ab,bx,xy", object = CoCoObject);

enterModel("ax,xy,yb", object = CoCoObject);

enterModel("xa,ab,by", object = CoCoObject);

# Show the model list:
showModel("all", object = CoCoObject);

n <- returnModelNumber("last", object = CoCoObject);
for (i in 1:n) {
  showFormula(i, object = CoCoObject);
  print(returnVertexOrder(i, object = CoCoObject));
}

endCoCo(CoCoObject);
}
\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{setOrdinal}
\alias{setOrdinal}

\title{ Declare some of the discrete variables to be ordinal }

\description{ Declare some of the discrete variables to be ordinal. }

\usage{
setOrdinal(set = "*", setslot = TRUE, data = NULL, 
           object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{set}{ A character string with the ordinal variables \code{set}. }
  \item{setslot}{ Logical, if \code{setslot} is TRUE then
                  \code{set} is added to \code{object}. }
  \item{data}{ ( See \code{\link{exportCoCo}}. ) }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ ( Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. ) }
}

\details{ }

\value{ A character sting with the ordinal variables \code{set}.  }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\seealso{\code{\link{enterDataFrame}},
         \code{\link{partialAssociations}}, \code{\link{optionsCoCo}},
         \code{\link{showDeviance}},
         \code{\link{returnTest}}, \code{\link{returnDeviance}}, 
         \code{\link{backward}} and \code{\link{forward}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{setUseVariables}
\alias{setUseVariables}

\title{ Declare which variables to enter }

\description{
	Between entering specification and observations,
	declare which variables to enter into the CoCo object.
}

\usage{
setUseVariables(hit = "all", set = ";", setslot = FALSE, data = NULL,
                object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{hit}{ Character string with \code{"all"}, \code{"what"}
	       or a set of variables. }
  \item{set}{ Character string with set of variables. }
  \item{setslot}{  See \code{\link{enterNames}}. }
  \item{data}{ ( See \code{\link{exportCoCo}}. ) }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ ( Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. ) }
}

% \details{ }

\value{ A character sting with the variables \code{set} to use.  }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\seealso{ \code{\link{returnNcells}} for example. }

\examples{
library(CoCo);
data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);
numberVariates(object = CoCoObject);

Specification <- returnVariableDescription(object = CoCoObject);
setUseVariables(paste(Specification$names[c(1,3,4,6)], collapse = ""), 
                object = CoCoObject);
enterTable(c(Reinis), object = CoCoObject);
numberVariates(object = CoCoObject);
numberVariates(full = TRUE, object = CoCoObject);

showOptions("specification", object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{showDeviance}
\alias{showDeviance}

\title{ Show the difference between likelihoods, dimension, etc. }

\description{
  Print on standard output the test statistics (deviance and F-test statistics)
  with p-values based on likelihoods and dimensions of the two argument
  models. For discrete models the adjustment of the degrees of freedom
  is also reported.
}

\usage{
showDeviance(model.1 = "current", model.2 = "base", data = NULL, 
             object = .object.of.models(model.1, model.2, data = data, ...), ...)
}

\arguments{
  \item{model.1}{ See \code{\link{isSubmodel}}. }
  \item{model.2}{ See \code{\link{isSubmodel}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{}

\value{
  The value TRUE is returned.
  If an error occurs then a warning is printed.
}

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ Something is wrong inversion 1.6.1 for \code{\link{showTest}},
%        \code{\link{returnTest}}, and \code{\link{backward}}:
%        Homogene models are produced in backward,
%        but tests are preformed as the models are inhomogene? }

\seealso{\code{\link{enterModel}}, \code{\link[CoCoObjects]{makeModel}},
         \code{\link{showModel}}, \code{\link{makeCurrent}},
         \code{\link{returnModel}}, \code{\link{returnModelNumber}},
         \code{\link{partialAssociations}}, \code{\link{optionsCoCo}},
         \code{\link{showTest}}, 
         \code{\link{returnTest}}, \code{\link{returnDeviance}},
         \code{\link{backward}} and \code{\link{forward}}. }

\examples{

library(MASS);
data(anorexia);
library(CoCoCg);

# showDeviance(model.1 ="[[:Prewt:Postwt][:Treat:Postwt]];",
#              model.2 ="*;", data = anorexia);
# endCoCo();

#

CoCoObject <- makeCoCoCg();
enterDataFrame(anorexia, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

# fullGraph <- dynamic.Graph(fullModel, title = "Full");

backward(recursive = TRUE, object = CoCoObject);

# lastModel <- makeModel("last", object = CoCoObject);
# backwardGraph <- dynamic.Graph(lastModel, title = "Last");

showModel("all", object = CoCoObject);
makeCurrent(object = CoCoObject);

# These two calls does not produce the same deviance,
# since the second correctly tests the inhomogene model:

showTest(object = CoCoObject);
showDeviance(object = CoCoObject);

# The default models for showTest and showDeviance are "current" and "base",
# but the default models for returnTest and returnDeviance was/are FALSE,
# which both will refer to "base" when no models are set:

returnTest(object = CoCoObject); # model.1 was/is by default "base"!!!
returnTest(FALSE, FALSE, object = CoCoObject);
returnTest("base", "base", object = CoCoObject);
returnTest("current", object = CoCoObject);
returnTest("current", "base", object = CoCoObject);
returnTest(model.2 = 1, object = CoCoObject);
returnTest("base", "current", object = CoCoObject);

returnDeviance(object = CoCoObject); # model.1 was/is by default "base"!!!
returnDeviance(FALSE, FALSE, object = CoCoObject);
returnDeviance("base", "base", object = CoCoObject);
returnDeviance("current", object = CoCoObject);
returnDeviance("current", "base", object = CoCoObject);
returnDeviance(model.2 = 1, object = CoCoObject);
returnDeviance("base", "current", object = CoCoObject);

showTest(3, 1, object = CoCoObject);
showDeviance(3, 1, object = CoCoObject);
returnTest(3, 1, object = CoCoObject);
returnDeviance(3, 1, object = CoCoObject);

showTest(1, 1, object = CoCoObject);
showDeviance(1, 1, object = CoCoObject);
returnTest(1, 1, object = CoCoObject);
returnDeviance(1, 1, object = CoCoObject);

# inhoModel <- makeModel(enterModel("[[:Treat]] / [[:Prewt][:Treat:Postwt]] / [[:Treat:Prewt:Postwt]]", object = CoCoObject));

# inhoModel <- makeModel(enterModel("[[:Treat]] / [[:Prewt][:Treat:Postwt]] / [:Prewt^][:Treat:Prewt:Postwt][:Treat:Postwt^]]", object = CoCoObject));

# inhoModel <- makeModel(enterModel("[[:Treat]] / [[:Prewt][:Treat:Postwt]] / [:Prewt^][:Prewt:Postwt][:Treat:Postwt^]]", object = CoCoObject));

inhoModel <- makeModel(enterModel("[[:Prewt:Postwt][:Treat:Postwt]]", object = CoCoObject));

showModel("all", object = CoCoObject);
makeCurrent(object = CoCoObject);

showTest(object = CoCoObject);
showDeviance(object = CoCoObject);
returnTest("current", "base", object = CoCoObject);
returnDeviance("current", "base", object = CoCoObject);

exportCoCo("anorexia.xpt");

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{showFormula}
\alias{showFormula}

\title{ Show the model formula }

\description{ Print on standard output the expression for estimating
	      the parameters of the model.
}

\usage{
showFormula(model = FALSE, data = NULL, 
            object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{returnModel}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{showModel}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{showModel}
\alias{showModel}

\title{ Show the model }

\description{ Print on standard output the model.
	      The model can also be given a longer description with
	      adjacency matrix and expression for estimates.
}

\usage{
showModel(model = FALSE, a = FALSE, b = FALSE, describe.model = FALSE, 
          data = NULL, object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ Numeric, model object, text string, or logical.
	 A numeric should give a valid model number in the \code{object},
         see \code{\link{makeCurrent}} about the model list.
         The argument can also be a CoCo model object, see
         \code{\link[CoCoObjects]{makeModel}} about creating model objects.
         The text strings \code{"base"}, \code{"current"}, or \code{"last"}
         refers to the three models.
	 The text strings \code{"interval"} will show the interval
	 given by the arguments \code{a} and \code{b}.
         The default value \code{"current"} for the CURRENT model
         can also be given as the logical FALSE (or NULL).
	 \code{model} can also be a vector or list with the above,
	 but not recursive.
         \code{model} can not be a character string with a generating class.
	 }
  \item{a}{ Numeric, \code{a} is the first model of the interval. }
  \item{b}{ Numeric, \code{b} is the last model of the interval. }
  \item{describe.model}{ Logical, if \code{describe.model} is TRUE
			 the the longer description is given. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{enterModel}} and \code{\link{makeCurrent}}. }

\examples{
library(CoCo);
data(Byssinosis38);
CoCoObject <- makeCoCo();
enterTable(Byssinosis38, object = CoCoObject);

# Generate some models:

enterModel("*", object = CoCoObject);
backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, 
         follow = TRUE, object = CoCoObject);
backwardResult <- returnModelNumber("last", object = CoCoObject);
enterModel(".;", object = CoCoObject);
forward(recursive = TRUE, headlong = TRUE, coherent = TRUE, object = CoCoObject);
makeCurrent(backwardResult, object = CoCoObject);

# Show the models:

showModel("all", object = CoCoObject);
showModel("last", object = CoCoObject);
showModel("base", object = CoCoObject);
showModel("current", object = CoCoObject);
showModel("number", 3, object = CoCoObject);

#  showModel(FALSE, object = CoCoObject);
#  showModel(TRUE, object = CoCoObject);
#  showModel(NULL, object = CoCoObject);

#  showModel(c(1, 2, c(7)), object = CoCoObject);
#  showModel("list", list(1, 2), object = CoCoObject);

#  showModel(c("current", 7, 9, "last"), object = CoCoObject);
#  showModel(c("current", "base", "last"), object = CoCoObject);

#  showModel("list", list("current", 2), object = CoCoObject);

# Show the model "backwardResult" down to 1:

while(makeCurrent("previous", 
                  object = CoCoObject)) showModel(object = CoCoObject);

# Show the model 10 to 15 3 times:

showModel(10:15, object = CoCoObject);

showModel("interval", 10, 15, object = CoCoObject);

makeCurrent(10, object = CoCoObject)
while(returnModelNumber("current", object = CoCoObject) < 15) {
	 makeCurrent("next", object = CoCoObject); 
	 showModel(object = CoCoObject); }

makeCurrent(backwardResult, object = CoCoObject);

showModel(6, describe.model = TRUE, object = CoCoObject);
showModel("current", describe.model = TRUE, object = CoCoObject);

showModel(1, describe.model = TRUE, object = CoCoObject);

# "base" and "last" gives shorter description:

showModel("base", describe.model = TRUE, object = CoCoObject);
showModel("last", describe.model = TRUE, object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{showOptions}
\alias{showOptions}

\title{ Show the options of the CoCo object }

\description{ Print on standard output the options of the CoCo object. }

\usage{
showOptions(hit = "all", dump = FALSE, data = NULL, 
            object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{hit}{ A character string \code{"all"}, \code{"formats"}, 
              \code{"tests"}, \code{"exact"}, \code{"fix"}, \code{"ips"}, 
              \code{"cips"}, \code{"mips"}, \code{"em"}, \code{"old"}, 
              \code{"specification"}, \code{"factors"}, \code{"observations"}, 
              \code{"data"}, \code{"limits"}, \code{"files"}, \code{"other"}, 
              \code{"search"}, or \code{"eh"}. }
  \item{dump}{ Logical, if \code{dump} is TRUE, then write CoCo commands for
	       setting the options. Only implemented for CoCoCg. }
  \item{data}{ ( See \code{\link{exportCoCo}}. ) }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ ( Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. ) }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\seealso{ \code{\link{optionsCoCo}}. }

\examples{
library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
showOptions(object = CoCoObject);
showOptions("specification", object = CoCoObject);

sinkCoCo(file.name = "Diary.tmp", type = "diary", object = CoCoObject);
showOptions("formats", object = CoCoObject);
showOptions("formats", dump = TRUE, object = CoCoObject);

sinkCoCo(file.name = "Diary.tmp", type = "diary", object = CoCoObject);
showOptions("tests", object = CoCoObject);
showOptions("tests", dump = TRUE, object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{showTable}
\alias{showTable}

\title{ The counts and fitted values of a marginal table }

\description{ Print on standard output the observed probabilities,
	      counts, means, covariance matrix, canonical parameters,
	      fitted values, residuals, etc. of marginal tables. }

\usage{
showTable(type = "observed", set = "*", model = FALSE, 
          random = FALSE, log.transformed = FALSE, complete = FALSE, 
          discrete.ordered = TRUE, table = FALSE, matrix = TRUE, 
          mixed = FALSE, output.form = "table", data = NULL, 
          object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{type}{ A character string.
	       The argument \code{type} for discrete variables:
	       \code{"counts"}, %           "0"  
	       \code{"probabilities"}, %    "1"  
	       \code{"expected"}, % 	    "2"  
	       \code{"unadjusted"}, % 	    "3"  
	       \code{"absolute"}, % 	    "3"  
	       \code{"f-res"}, % 	    "4"  
	       \code{"r-f"}, %  	    "5"  
	       \code{"g-res"}, % 	    "6"  
	       \code{"r-g"}, %		    "7"  
	       \code{"adjusted"}, % 	    "8"  
	       \code{"c-res"}, % 	    "8"  
	       \code{"m-res"}, % 	    "9"  
	       \code{"standardized"}, %     "9"  
	       \code{"standard"}, % 	    "9"  
	       \code{"x-res"}, % 	    "9"  
	       \code{"l-res"}, % 	    "10" 
	       \code{"freeman-tukey"}, %    "11" 
	       \code{"sqrt"}, % 	    "12" 
	       \code{"power"}, % 	    "13" 
	       \code{"index"}, % 	    "14" 
	       \code{"zero"}, % 	    "15" 
	       \code{"error"}. % 	    "63" 

	       The argument \code{type} for both discrete and
	       continuous variables:
	       \code{"leverage"}, % 	    "16" 
	       \code{"canonical"}, % 	    "18" 
	       \code{"gs"}, % 		    "19" 
	       \code{"hs"}, % 		    "20" 
	       \code{"ks"}, % 		    "21" 
	       \code{"moment"}, % 	    "22" 
	       \code{"means"}, % 	    "23" 
	       \code{"covariance"}, % 	    "24" 
	       \code{"raw"}, %		    "25" 
	       \code{"total"}, % 	    "26" 
	       \code{"ss"}, % 		    "27" 
	       \code{"ssds"}, % 	    "28" 
	       \code{"determinants"}, %     "29" 
	       \code{"mk"}, % 		    "30" 
	       \code{"ms"}. % 		    "31" 

 }
  \item{set}{ A character string with the \code{set} of variables. }
  \item{model}{ See \code{\link{returnModel}}. }
  \item{random}{ Logical, if \code{random} then a random table
		 with counts in the sufficient marginal tables
		 as in the observed table is generated,
		 and the values are are computed for this random table. }
  \item{log.transformed}{ Logical, if TRUE then the values are
			   \code{log.transformed} before printed. }
  \item{complete}{ Logical, if \code{complete} is TRUE then
		   no value is returned for cells to be zero
		   by structure. }
  \item{discrete.ordered}{ Logical, if \code{discrete.ordered} then
			   the variables are ordered as specified
			   by the call. }
  \item{table}{ Logical, for CoCoCg objects.
		If \code{table} is FALSE then for each configuration
		in the cross classification of the discrete variables
		the means and covariances of the continuous variables
		are printed according to the argument \code{matrix}.
		If \code{table} is TRUE then for each mean
		and for each covariance a table formed by the
		cross classification of the discrete variables
		is printed with the quantity. }
  \item{matrix}{ Logical, for CoCoCg objects.
		If \code{matrix} is TRUE then the means and covariances
		are printed in a matrix with the continuous variables
		as headings, else all the quantities for the continuous
		variables are printed on a single line for each configuration
		in the cross classification of the discrete variables. }
  \item{mixed}{ Logical, if \code{mixed} is TRUE then mixed
		quantities are printed.. }
  \item{output.form}{ A character string.
		      The argument \code{output.form} is only
		      used for only discrete variables:
		      \code{"table"} for the table of the value selected by
				     the argument \code{type},
		      \code{"sparse.table"} for a list of counts in cells
					    with count different for zero,
		      \code{"case.list"} for a case list,
		      or, \code{"list.all.values"} for a list of all the
		      values for discrete variables. }

  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

\details{
	\itemize{
	\item{Marginal model }{:}   
	\item{ Observed }{: (or \code{"counts"})} %		"0"
	\item{ Probabilities }{: } %	"1"
	\item{ Expected }{: } %		"2"
	\item{ Unadjusted }{: (or \code{"absolute"})} %	"3"
	\item{ F-res }{: } %		"4"
	\item{ R-f }{: } %		"5"
	\item{ G-res }{: } %		"6"
	\item{ R-g }{: } %		"7"
	\item{ Adjusted }{: } %		"8"
	\item{ C-res }{: } %		"8"
	\item{ Standardized }{: (or \code{"m-res"},
				    \code{"x-res"}, or
                                    \code{"standard"}) } %	"9"
	\item{ X-res }{: } %		"9"
	\item{ Deviance }{: (or \code{"l-res"} or
			        \code{"-2log"})} %		"10"
	\item{ Freeman-tukey }{: } %	"11"
	\item{ Sqrt }{: (or \code{"2n-m"})} %		"12"
	\item{ Power }{: } %		"13"
	\item{ Index }{: } %		"14"
	\item{ Zero }{: } %		"15"
	\item{ Leverage }{: } %		"16"
	\item{ Canonical }{: } %	"18"
	\item{ Gs }{: } %		"19"
	\item{ Hs }{: } %		"20"
	\item{ Ks }{: } %		"21"
	\item{ Moment }{: } %		"22"
	\item{ Means }{: } %		"23"
	\item{ Covariance }{: } %	"24"
	\item{ Raw }{: } %		"25"
	\item{ Total }{: } %		"26"
	\item{ Ss }{: } %		"27"
	\item{ Ssds }{: (or \code{"sigma"}) } %		"28"
	\item{ Determinants }{: } %	"29"
	\item{ Mk }{: } %		"30"
	\item{ Ms }{: } %		"31"
	\item{ Error }{: } %		"63"
    }
    \itemize{
	\item{ Table }{: } % 
	\item{ Sparse table }{: } %
	\item{ Case list }{: } % 
	\item{ List all values }{: } % 
    }
}

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{summaryTable}}. }

\examples{
library(CoCoCg);
library(MASS)
data(crabs);

crabsCoCo <- makeCoCoCg();
result <- enterDataFrame(crabs[,-3], object = crabsCoCo);

enterModel("*;", object = crabsCoCo);

showTable("observed", "[:sp:sex]", object = crabsCoCo);

showTable("canonical", "[:sp:sex:FL:RW:CL:CW:BD]", 
		       matrix = TRUE, object = crabsCoCo);

showTable("canonical", "[:sp:sex:FL:RW:CL:CW:BD]", matrix = TRUE);

showTable("moment", "[:sp:sex:FL:RW:CL:CW:BD]", 
		       matrix = TRUE, object = crabsCoCo);

returnTable("canonical", "[:sp:sex:FL:RW:CL:CW:BD]");

returnTable("mk", "[:sp:sex:FL:RW:CL:CW:BD]");

# backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, follow = TRUE, 
#          object = crabsCoCo);

m5 <- "[[:sp:sex]] / [[:sp:sex:FL][:sp:sex:RW][:sex:CL][:sp:sex:BD][:sp:sex:CW]] / [[:sex:FL:CL][:sp:sex:FL:CW][:sp:sex:FL:BD][:sp:sex:RW:CW][:sex:CL:CW][:sex:CL:BD][:sp:sex:CW:BD]]"
m4 <- "[[:sp:sex]] / [[:sp:sex:RW][:sp:sex:BD][:sp:sex:CW][:sp:sex:FL][:sex:CL]] / [[:sp:sex:CW:BD][:sex:CL:BD][:sex:CL:CW][:sp:sex:RW:BD][:sp:sex:RW:CW][:sp:sex:FL:BD][:sp:sex:FL:CW][:sex:FL:CL]]"
m3 <- "[[:sp:sex]] / [[:sp:sex:FL][:sp:sex:RW][:sex:CL][:sp:sex:BD][:sp:sex:CW]] / [[:sp:sex:FL:RW][:sex:FL:CL][:sp:sex:FL:CW][:sp:sex:FL:BD][:sp:sex:RW:CW][:sp:sex:RW:BD][:sex:CL:CW][:sex:CL:BD][:sp:sex:CW:BD]]"
m2 <- "[[:sp:sex]] / [[:sp:sex:BD][:sp:sex:CW][:sex:CL][:sp:sex:RW][:sp:sex:FL]] / [[:sp:sex:CW:BD][:sex:CL:BD][:sex:CL:CW][:sp:sex:RW:BD][:sp:sex:RW:CW][:sex:RW:CL][:sp:sex:FL:BD][:sp:sex:FL:CW][:sex:FL:CL][:sp:sex:FL:RW]]"
m1 <- "[[:sp:sex]] / [[:sp:sex:BD][:sp:sex:CW][:sp:sex:CL][:sp:sex:RW][:sp:sex:FL]] / [[:sp:sex:CW:BD][:sp:sex:CL:BD][:sp:sex:CL:CW][:sp:sex:RW:BD][:sp:sex:RW:CW][:sp:sex:RW:CL][:sp:sex:FL:BD][:sp:sex:FL:CW][:sp:sex:FL:CL][:sp:sex:FL:RW]]"

enterModel(m1, object = crabsCoCo);
enterModel(m2, object = crabsCoCo);
enterModel(m3, object = crabsCoCo);
enterModel(m4, object = crabsCoCo);
enterModel(m5, object = crabsCoCo);

makeCurrent("last", object = crabsCoCo)
returnTable("mk", "[:sp:sex:FL:RW:CL:CW:BD]");

Rfirst <- returnTable("mk", "[:sp:sex:FL:RW:CL:CW:BD]", model = 1);
Rlast  <- returnTable("mk", "[:sp:sex:FL:RW:CL:CW:BD]", model = 6);
Sfirst <- returnTable("ms", "[:sp:sex:FL:RW:CL:CW:BD]", model = 1);
Slast  <- returnTable("ms", "[:sp:sex:FL:RW:CL:CW:BD]", model = 6);

Rfirst$h-Rlast$h
Rfirst$K-Rlast$K
Sfirst$Mean-Slast$Mean

endCoCo(object = crabsCoCo);

}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{showTest}
\alias{showTest}
\title{ Show the Pearson $\chi^2$, the power divergence, etc. }

\description{
 Print on standard output for discrete data
 the Pearson $\chi^2$, the power divergence, and the deviance,
 and for tests of two ordinal variable conditional independent
 given discrete also the Goodman and Kruskal's Gamma coefficient,
 and for mixed data the deviance and the F-test statistic, all with p-values.
 For discrete data also exact p-values can be printed.
}

\usage{
showTest(model.1 = "current", model.2 = "base", exact.test = NULL, 
         break.down = "", set = ";", only.if.one.edge = FALSE, data = NULL, 
         object = .object.of.models(model.1, model.2, data = data, ...), ...)
}

\arguments{
  \item{model.1}{ See \code{\link{isSubmodel}}. }
  \item{model.2}{ See \code{\link{isSubmodel}}. }
  \item{exact.test}{ Logical, if \code{exact.test} is TRUE then exact p-values
		     are computed by Monte Carlo simulation. }
  \item{break.down}{ Text-string:  
  \code{"edges"}: Break down the test in a sequence of tests,
	   each test a test between two models differing by one edge.
	   The order of the edges are controlled by the argument \code{set}.
  \code{"interactions"}: Break down the test in a sequence of tests, each test 
		  a test between two models differing by one interaction term.
		  The order of the terms are controlled by
		  the argument \code{set}.
  \code{"components"}:  Find sets that are complete separators for both models,
		 and show tests collapsed to each component.
  \code{"show.common.decompositions"}:  Do not perform a test, show
				 separators which are complete in both models.
  \code{"decompose.models"}: Do not perform a test, but decompose both
		      models with respect to the argument \code{set}.
		      }
  \item{set}{ Text string with set of variables,
	      see the argument \code{break.down}. }
  \item{only.if.one.edge}{ Logical, if \code{only.if.one.edge} is set to TRUE
			   then the test is only performed
			   if the models differs with one edge and only
			   one edge. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ % Something is wrong inversion 1.6.1 for \code{\link{showTest}},
       % \code{\link{returnTest}}, and \code{\link{backward}}:
       % Homogene models are produced in backward,
       % but tests are preformed as the models are inhomogene?

       }

\seealso{\code{\link{enterModel}}, \code{\link[CoCoObjects]{makeModel}},
         \code{\link{showModel}}, \code{\link{makeCurrent}},
         \code{\link{returnModel}}, \code{\link{returnModelNumber}},
         \code{\link{partialAssociations}}, \code{\link{optionsCoCo}},
         \code{\link{showDeviance}},
         \code{\link{returnTest}}, \code{\link{returnDeviance}}, 
         \code{\link{backward}} and \code{\link{forward}}. }

\examples{ 
# data(HairEyeColor);
# library(CoCo);
# showTest(":H:S,:E:S", "*", data = HairEyeColor, exact.test = "on");
# endCoCo();

library(MASS);
data(cabbages);
library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(cabbages, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, 
         follow = TRUE, object = CoCoObject);

makeCurrent("last", object = CoCoObject);
showTest("last", object = CoCoObject);

returnTable("moment", ":Cult:Date:HeadWt:VitC", object = CoCoObject);
returnTable("moment", ":Cult:Date:HeadWt:VitC", matrix = TRUE, 
            object = CoCoObject);

returnTable("mk", ":Cult:Date:HeadWt:VitC", matrix = TRUE, 
            object = CoCoObject);

showTable("mk", ":Cult:Date:HeadWt:VitC", matrix = TRUE, 
           object = CoCoObject);

showTable("mk", ":Cult:Date:HeadWt:VitC", 
           object = CoCoObject);

showTable("ms", ":Cult:Date:HeadWt:VitC", 
           object = CoCoObject);

endCoCo(CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{showTests}
\alias{showTests}
\title{ Show all the stored tests of a CoCo object }
\description{
  Print on standard output all the stored tests in the CoCo object.
}

\usage{
showTests(data = NULL, object = .object.of.thing(data = data, ...), ...)
}

\arguments{
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

\note{ Reuse of tests in the CoCo object can be turned of by
       \code{optionsCoCo(reuse.tests=FALSE)}. Thus no tests
       are inserted into the test list of the CoCo object.
}

\seealso{\code{\link{optionsCoCo}},
         \code{\link{showTest}}, \code{\link{showDeviance}},
         \code{\link{returnTest}}, \code{\link{showTest}}, \code{\link{eh}},
         \code{\link{backward}} and \code{\link{forward}}. }

\examples{
library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE,
         coherent = TRUE, follow = TRUE, object = CoCoObject);

# Show the model list:
showModel("all", object = CoCoObject);

showTests(object = CoCoObject);

endCoCo(object = CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{showVertexOrder}
\alias{showVertexOrder}

\title{ Show the vertex ordering }

\description{ Print on standard output the vertex ordering used to decompose
	      the model. }

\usage{
showVertexOrder(model = FALSE, data = NULL, 
                object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{model}{ See \code{\link{returnModel}}. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{ Badsberg, J.H.: A guide to CoCo, JSS, 2001
             ( http://www.jstatsoft.org/v06/i04/ )
             and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{ Jens Henrik Badsberg }

% \note{ }

\seealso{ \code{\link{returnVertexOrder}}. }

\examples{
library(CoCo);
data(Reinis);
CoCoObject <- makeCoCo();
enterTable(Reinis, object = CoCoObject);

# Enter the saturated model:	
enterModel("*", object = CoCoObject);

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE, 
         coherent = TRUE, follow = TRUE, object = CoCoObject);

# Show the model list:
showModel("all", object = CoCoObject);

n <- returnModelNumber("last", object = CoCoObject);
for (i in 1:n) {
  showFormula(i, object = CoCoObject);
  showVertexOrder(i, object = CoCoObject);
}

endCoCo(CoCoObject);

library(CoCoCg);
data(Rats);
CoCoObject <- makeCoCoCg();
enterDataFrame(Rats, object = CoCoObject);
fullModel <- makeModel(enterModel("*", object = CoCoObject));

# Generate some models, here by "backward":
backward(recursive = TRUE, headlong = TRUE, coherent = TRUE, 
         follow = TRUE, object = CoCoObject);

homogeneModel <- makeModel(enterModel("[[ab]] / [[aby][abx]] / [[x^][abxy][y^]]",
	                     object = CoCoObject));

enterModel("ab,bx,xy", object = CoCoObject);

enterModel("ax,xy,yb", object = CoCoObject);

enterModel("xa,ab,by", object = CoCoObject);

# Show the model list:
showModel("all", object = CoCoObject);

n <- returnModelNumber("last", object = CoCoObject);
for (i in 1:n) {
  showFormula(i, object = CoCoObject);
  # showVertexOrder(i, object = CoCoObject); # Fault !!!!
}

endCoCo(CoCoObject);
}

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{sinkCoCo}
\alias{sinkCoCo}

\title{ Direct output to a file }

\description{ Diverts CoCo output to a file. }

\usage{
sinkCoCo(file.name = "Diary.tmp", type = "diary", object = .current.coco)
}

\arguments{
  \item{file.name}{ A character string naming the file to write to.
     To return the file name set the \code{file.name} to \code{"what"}. }
  \item{type}{ Textstring with \code{"output"}, \code{"log"}, \code{"diary"},
  \code{"report"}, or \code{"dump"}. 
 }
  \item{object}{ See \code{\link{exportCoCo}}. }
}

\details{ The output from CoCo to standard output consists of \code{"output"}
	  form the procedures and echo, \code{"log"}, from the parser.
	  Both parts can be copied to the \code{"diary"}.
	  Number of cycles in iterative algorithmes and simular
	  are reported in \code{"report"}.
	  Some output, from e.g. \code{\link{returnTable}},
	  can be written to the \code{"dump"} file.
}

\value{ The text string with the file name. }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{  }

\seealso{ \code{\link{showOptions}} and \code{\link{optionsCoCo}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
\name{summaryTable}
\alias{summaryTable}

\title{ Univariate summary statistics for table values }

\description{ Print on standard output univariate summary statistics, 
	      histogram, and uniform and quantile-quantile plots
	      of values in marginal tables. }

\usage{
summaryTable(type = "observed", set = "*", model = FALSE, random = FALSE, 
             log.transformed = FALSE, complete = FALSE, uniform = FALSE, 
             rankit = FALSE, probit = FALSE, data = NULL, 
             object = .object.of.model(model, data = data, ...), ...)
}

\arguments{
  \item{type}{ A character string.
	       The argument \code{type} for discrete variables:
	       \code{"counts"}, %           "0"  
	       \code{"probabilities"}, %    "1"  
	       \code{"expected"}, % 	    "2"  
	       \code{"unadjusted"}, % 	    "3"  
	       \code{"absolute"}, % 	    "3"  
	       \code{"f-res"}, % 	    "4"  
	       \code{"r-f"}, % 		    "5"  
	       \code{"g-res"}, % 	    "6"  
	       \code{"r-g"}, % 		    "7"  
	       \code{"adjusted"}, % 	    "8"  
	       \code{"c-res"}, % 	    "8"  
	       \code{"m-res"}, % 	    "9"  
	       % \code{"standardized"}, %     "9"  
	       \code{"standard"}, % 	    "9"  
	       \code{"x-res"}, % 	    "9"  
	       \code{"l-res"}, % 	    "10" 
	       \code{"freeman-tukey"}, %    "11" 
	       \code{"sqrt"}, %	       	    "12" 
	       \code{"power"}, % 	    "13" 
	       \code{"index"}, % 	    "14" 
	       \code{"zero"}, %		    "15" 
	       \code{"error"}. % 	    "63" 
	       See also \code{\link{showTable}}. 
	       }
  \item{set}{ See \code{\link{showTable}}. }
  \item{model}{ See \code{\link{returnModel}}. }
  \item{random}{ See \code{\link{showTable}}. }
  \item{log.transformed}{ See \code{\link{showTable}}. }
  \item{complete}{ See \code{\link{showTable}}. }
  \item{uniform}{ Logical, if \code{uniform} is TRUE
		  then a Q-Q-plot is plotted according to the argument. }
  \item{rankit}{ Logical, if \code{rankit} is TRUE
		  then a Q-Q-plot is plotted. }
  \item{probit}{ Logical, if \code{probit} is TRUE
		  then a Q-Q-plot is plotted. }
  \item{data}{ See \code{\link{exportCoCo}}. }
  \item{object}{ See \code{\link{exportCoCo}}. }
  \item{\dots}{ Additional arguments to generate the CoCo \code{object}
	 from the \code{data} argument. See \code{\link{propertyModel}}. }
}

% \details{ }

\value{ TRUE }

\references{Badsberg, J.H.: A guide to CoCo, JSS, 2001
            ( http://www.jstatsoft.org/v06/i04/ )
            and Badsberg, J.H.: Xlisp+CoCo, Aalborg University, 1996. }

\author{Jens Henrik Badsberg}

% \note{ }

% \section{ToDo}{....}

\seealso{ \code{\link{showTable}}. }

% \examples{ }

\keyword{ methods }% at least one, from doc/KEYWORDS
\keyword{ multivariate }% __ONLY ONE__ keyword per line

\eof
